pub enum CreateError<E> {
FarmUser,
BotIsGhost,
GhostIsBot,
BotAlreadyTaken,
Desync,
Api(E),
}Available on crate feature
farm only.Variants
FarmUser
Farm user cannot be interacted with directly
BotIsGhost
Bot cannot be created because ghost with same name already exists
GhostIsBot
Ghost cannot be craeted because bot with same name already exists
BotAlreadyTaken
The bot already exists and was already taken with the take_bot
Desync
The in memory state is not synced with the DB, retry later
Api(E)