pub struct BotSettings {
pub display_name: String,
pub auto_accept: Option<String>,
pub profile_settings: Option<BotProfileSettings>,
pub avatar: Option<ImagePreview>,
}Expand description
Passed to Bot::init to configure bot identity and startup behaviour.
Fields
display_name: Stringauto_accept: Option<String>If string is empty creates an auto-accepting address without a message. If string is not empty adds a welcome message to the address
profile_settings: Option<BotProfileSettings>avatar: Option<ImagePreview>Implementations
Sourceimpl BotSettings
impl BotSettings
pub fn new(name: impl Into<String>) -> Self
pub fn with_avatar(self, avatar: ImagePreview) -> Self
Sourcepub fn auto_accept(self) -> Self
pub fn auto_accept(self) -> Self
Create a public auto-accepting address during the intialisation
Sourcepub fn auto_accept_with(self, welcome_message: impl Into<String>) -> Self
pub fn auto_accept_with(self, welcome_message: impl Into<String>) -> Self
Create a public auto-accepting address with a welcome meesage during the intialisation
pub fn with_profile_settings(self, settings: BotProfileSettings) -> Self