Module commands

Module commands 

Structs

ApiAcceptContact
Connection commands
ApiAcceptContactBuilder
Use builder syntax to set the inputs and finish with build().
ApiAcceptMember
Group commands
ApiAcceptMemberBuilder
Use builder syntax to set the inputs and finish with build().
ApiAddContact
Connection commands
ApiAddContactBuilder
Use builder syntax to set the inputs and finish with build().
ApiAddGroupRelays
Group commands
ApiAddGroupRelaysBuilder
Use builder syntax to set the inputs and finish with build().
ApiAddMember
Group commands
ApiAddMemberBuilder
Use builder syntax to set the inputs and finish with build().
ApiBlockMembersForAll
Group commands
ApiBlockMembersForAllBuilder
Use builder syntax to set the inputs and finish with build().
ApiChatItemReaction
Message commands
ApiChatItemReactionBuilder
Use builder syntax to set the inputs and finish with build().
ApiConnect
Connection commands
ApiConnectBuilder
Use builder syntax to set the inputs and finish with build().
ApiConnectPlan
Connection commands
ApiConnectPlanBuilder
Use builder syntax to set the inputs and finish with build().
ApiCreateGroupLink
Group link commands
ApiCreateGroupLinkBuilder
Use builder syntax to set the inputs and finish with build().
ApiCreateMyAddress
Address commands
ApiCreateMyAddressBuilder
Use builder syntax to set the inputs and finish with build().
ApiDeleteChat
Chat commands
ApiDeleteChatBuilder
Use builder syntax to set the inputs and finish with build().
ApiDeleteChatItem
Message commands
ApiDeleteChatItemBuilder
Use builder syntax to set the inputs and finish with build().
ApiDeleteGroupLink
Group link commands
ApiDeleteGroupLinkBuilder
Use builder syntax to set the inputs and finish with build().
ApiDeleteMemberChatItem
Message commands
ApiDeleteMemberChatItemBuilder
Use builder syntax to set the inputs and finish with build().
ApiDeleteMyAddress
Address commands
ApiDeleteMyAddressBuilder
Use builder syntax to set the inputs and finish with build().
ApiDeleteUser
User profile commands
ApiDeleteUserBuilder
Use builder syntax to set the inputs and finish with build().
ApiGetChats
Chat commands
ApiGetChatsBuilder
Use builder syntax to set the inputs and finish with build().
ApiGetGroupLink
Group link commands
ApiGetGroupLinkBuilder
Use builder syntax to set the inputs and finish with build().
ApiGetGroupRelays
Group commands
ApiGetGroupRelaysBuilder
Use builder syntax to set the inputs and finish with build().
ApiGroupLinkMemberRole
Group link commands
ApiGroupLinkMemberRoleBuilder
Use builder syntax to set the inputs and finish with build().
ApiJoinGroup
Group commands
ApiJoinGroupBuilder
Use builder syntax to set the inputs and finish with build().
ApiLeaveGroup
Group commands
ApiLeaveGroupBuilder
Use builder syntax to set the inputs and finish with build().
ApiListContacts
Chat commands
ApiListContactsBuilder
Use builder syntax to set the inputs and finish with build().
ApiListGroups
Chat commands
ApiListGroupsBuilder
Use builder syntax to set the inputs and finish with build().
ApiListMembers
Group commands
ApiListMembersBuilder
Use builder syntax to set the inputs and finish with build().
ApiMembersRole
Group commands
ApiMembersRoleBuilder
Use builder syntax to set the inputs and finish with build().
ApiNewGroup
Group commands
ApiNewGroupBuilder
Use builder syntax to set the inputs and finish with build().
ApiNewPublicGroup
Group commands
ApiNewPublicGroupBuilder
Use builder syntax to set the inputs and finish with build().
ApiRejectContact
Connection commands
ApiRejectContactBuilder
Use builder syntax to set the inputs and finish with build().
ApiRemoveMembers
Group commands
ApiRemoveMembersBuilder
Use builder syntax to set the inputs and finish with build().
ApiSendMessages
Message commands
ApiSendMessagesBuilder
Use builder syntax to set the inputs and finish with build().
ApiSetActiveUser
User profile commands
ApiSetActiveUserBuilder
Use builder syntax to set the inputs and finish with build().
ApiSetAddressSettings
Address commands
ApiSetAddressSettingsBuilder
Use builder syntax to set the inputs and finish with build().
ApiSetContactCustomData
Chat commands
ApiSetContactCustomDataBuilder
Use builder syntax to set the inputs and finish with build().
ApiSetContactPrefs
User profile commands
ApiSetContactPrefsBuilder
Use builder syntax to set the inputs and finish with build().
ApiSetGroupCustomData
Chat commands
ApiSetGroupCustomDataBuilder
Use builder syntax to set the inputs and finish with build().
ApiSetProfileAddress
Address commands
ApiSetProfileAddressBuilder
Use builder syntax to set the inputs and finish with build().
ApiSetUserAutoAcceptMemberContacts
Chat commands
ApiSetUserAutoAcceptMemberContactsBuilder
Use builder syntax to set the inputs and finish with build().
ApiShowMyAddress
Address commands
ApiShowMyAddressBuilder
Use builder syntax to set the inputs and finish with build().
ApiStopChat
Chat management
ApiStopChatBuilder
Use builder syntax to set the inputs and finish with build().
ApiUpdateChatItem
Message commands
ApiUpdateChatItemBuilder
Use builder syntax to set the inputs and finish with build().
ApiUpdateGroupProfile
Group commands
ApiUpdateGroupProfileBuilder
Use builder syntax to set the inputs and finish with build().
ApiUpdateProfile
User profile commands
ApiUpdateProfileBuilder
Use builder syntax to set the inputs and finish with build().
CancelFile
File commands
CancelFileBuilder
Use builder syntax to set the inputs and finish with build().
Connect
Connection commands
ConnectBuilder
Use builder syntax to set the inputs and finish with build().
CreateActiveUser
User profile commands
CreateActiveUserBuilder
Use builder syntax to set the inputs and finish with build().
ListUsers
User profile commands
ListUsersBuilder
Use builder syntax to set the inputs and finish with build().
ReceiveFile
File commands
ReceiveFileBuilder
Use builder syntax to set the inputs and finish with build().
ShowActiveUser
User profile commands
ShowActiveUserBuilder
Use builder syntax to set the inputs and finish with build().
StartChat
Chat management
StartChatBuilder
Use builder syntax to set the inputs and finish with build().