pub struct ApiAcceptContact {
pub contact_req_id: i64,
}Expand description
Connection commands
These commands may be used to create connections. Most bots do not need to use them - bot users will connect via bot address with auto-accept enabled.
Accept contact request.
Network usage: interactive.
Syntax:
/_accept <contactReqId>Fields
contact_req_id: i64Implementations
Sourceimpl ApiAcceptContact
impl ApiAcceptContact
Sourcepub fn builder() -> ApiAcceptContactBuilder
pub fn builder() -> ApiAcceptContactBuilder
Create an instance of ApiAcceptContact using the builder syntax