pub struct ApiAddContact {
pub user_id: i64,
pub incognito: bool,
}Expand description
Connection commands
These commands may be used to create connections. Most bots do not need to use them - bot users will connect via bot address with auto-accept enabled.
Create 1-time invitation link.
Network usage: interactive.
Syntax:
/_connect <userId>[ incognito=on]Fields
user_id: i64incognito: boolImplementations
Sourceimpl ApiAddContact
impl ApiAddContact
Sourcepub fn builder() -> ApiAddContactBuilder
pub fn builder() -> ApiAddContactBuilder
Create an instance of ApiAddContact using the builder syntax
Sourceimpl ApiAddContact
impl ApiAddContact
Sourcepub fn new(user_id: i64) -> ApiAddContact
pub fn new(user_id: i64) -> ApiAddContact
Creates a command with all Option parameters set to None and all bool parameters set to false