pub struct ApiAllowRelayGroup {
pub group_id: i64,
}Expand description
Group commands
Commands to manage and moderate groups. These commands can be used with business chats as well - they are groups. E.g., a common scenario would be to add human agents to business chat with the customer who connected via business address.
Clear relay rejection for a channel (relay operator).
Network usage: background.
Syntax:
/_relay allow #<groupId>Fields
group_id: i64Trait Implementations
Sourceimpl Clone for ApiAllowRelayGroup
impl Clone for ApiAllowRelayGroup
Sourcefn clone(&self) -> ApiAllowRelayGroup
fn clone(&self) -> ApiAllowRelayGroup
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CommandSyntax for ApiAllowRelayGroup
impl CommandSyntax for ApiAllowRelayGroup
const COMMAND_BUF_SIZE: usize = 64
fn append_command_syntax(&self, buf: &mut String)
Sourcefn to_command_string(&self) -> String
fn to_command_string(&self) -> String
Generate a SimpleX command string from self
Sourceimpl Debug for ApiAllowRelayGroup
impl Debug for ApiAllowRelayGroup
Sourceimpl PartialEq for ApiAllowRelayGroup
impl PartialEq for ApiAllowRelayGroup
Sourcefn eq(&self, other: &ApiAllowRelayGroup) -> bool
fn eq(&self, other: &ApiAllowRelayGroup) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ApiAllowRelayGroup