pub struct ApiGetGroupRelays {
pub group_id: i64,
}Expand description
Group commands
Commands to manage and moderate groups. These commands can be used with business chats as well - they are groups. E.g., a common scenario would be to add human agents to business chat with the customer who connected via business address.
Get group relays.
Network usage: no.
Syntax:
/_get relays #<groupId>Fields
group_id: i64Trait Implementations
Sourceimpl Clone for ApiGetGroupRelays
impl Clone for ApiGetGroupRelays
Sourcefn clone(&self) -> ApiGetGroupRelays
fn clone(&self) -> ApiGetGroupRelays
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CommandSyntax for ApiGetGroupRelays
impl CommandSyntax for ApiGetGroupRelays
const COMMAND_BUF_SIZE: usize = 64
fn append_command_syntax(&self, buf: &mut String)
Sourcefn to_command_string(&self) -> String
fn to_command_string(&self) -> String
Generate a SimpleX command string from self
Sourceimpl Debug for ApiGetGroupRelays
impl Debug for ApiGetGroupRelays
Sourceimpl PartialEq for ApiGetGroupRelays
impl PartialEq for ApiGetGroupRelays
Sourcefn eq(&self, other: &ApiGetGroupRelays) -> bool
fn eq(&self, other: &ApiGetGroupRelays) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ApiGetGroupRelays