pub struct ApiListGroups {
pub user_id: i64,
pub contact_id: Option<i64>,
pub search: Option<String>,
}Expand description
Chat commands
Commands to list and delete conversations.
Get groups.
Network usage: no.
Syntax:
/_groups <userId>[ @<contactId_>][ <search>]Fields
user_id: i64contact_id: Option<i64>search: Option<String>Implementations
Sourceimpl ApiListGroups
impl ApiListGroups
Sourcepub fn builder() -> ApiListGroupsBuilder
pub fn builder() -> ApiListGroupsBuilder
Create an instance of ApiListGroups using the builder syntax
Sourceimpl ApiListGroups
impl ApiListGroups
Sourcepub fn new(user_id: i64) -> ApiListGroups
pub fn new(user_id: i64) -> ApiListGroups
Creates a command with all Option parameters set to None and all bool parameters set to false