pub struct ApiMembersRole {
pub group_id: i64,
pub group_member_ids: Vec<i64>,
pub member_role: GroupMemberRole,
}Expand description
Group commands
Commands to manage and moderate groups. These commands can be used with business chats as well - they are groups. E.g., a common scenario would be to add human agents to business chat with the customer who connected via business address.
Set members role. Requires Admin role.
Network usage: background.
Syntax:
/_member role #<groupId> <groupMemberIds[0]>[,<groupMemberIds[1]>...] relay|observer|author|member|moderator|admin|ownerFields
group_id: i64group_member_ids: Vec<i64>member_role: GroupMemberRoleImplementations
Sourceimpl ApiMembersRole
impl ApiMembersRole
Sourcepub fn builder() -> ApiMembersRoleBuilder
pub fn builder() -> ApiMembersRoleBuilder
Create an instance of ApiMembersRole using the builder syntax