pub struct ApiNewGroup {
pub user_id: i64,
pub incognito: bool,
pub group_profile: GroupProfile,
}Expand description
Group commands
Commands to manage and moderate groups. These commands can be used with business chats as well - they are groups. E.g., a common scenario would be to add human agents to business chat with the customer who connected via business address.
Create group.
Network usage: no.
Syntax:
/_group <userId>[ incognito=on] <json(groupProfile)>Fields
user_id: i64incognito: boolgroup_profile: GroupProfileImplementations
Sourceimpl ApiNewGroup
impl ApiNewGroup
Sourcepub fn builder() -> ApiNewGroupBuilder
pub fn builder() -> ApiNewGroupBuilder
Create an instance of ApiNewGroup using the builder syntax
Sourceimpl ApiNewGroup
impl ApiNewGroup
Sourcepub fn new(user_id: i64, group_profile: GroupProfile) -> ApiNewGroup
pub fn new(user_id: i64, group_profile: GroupProfile) -> ApiNewGroup
Creates a command with all Option parameters set to None and all bool parameters set to false