pub struct ApiNewPublicGroup {
pub user_id: i64,
pub incognito: bool,
pub relay_ids: Vec<i64>,
pub group_profile: GroupProfile,
}Expand description
Group commands
Commands to manage and moderate groups. These commands can be used with business chats as well - they are groups. E.g., a common scenario would be to add human agents to business chat with the customer who connected via business address.
Create public group.
Network usage: interactive.
Syntax:
/_public group <userId>[ incognito=on] <relayIds[0]>[,<relayIds[1]>...] <json(groupProfile)>Fields
user_id: i64incognito: boolrelay_ids: Vec<i64>group_profile: GroupProfileImplementations
Sourceimpl ApiNewPublicGroup
impl ApiNewPublicGroup
Sourcepub fn builder() -> ApiNewPublicGroupBuilder
pub fn builder() -> ApiNewPublicGroupBuilder
Create an instance of ApiNewPublicGroup using the builder syntax
Sourceimpl ApiNewPublicGroup
impl ApiNewPublicGroup
Sourcepub fn new(
user_id: i64,
relay_ids: Vec<i64>,
group_profile: GroupProfile,
) -> ApiNewPublicGroup
pub fn new( user_id: i64, relay_ids: Vec<i64>, group_profile: GroupProfile, ) -> ApiNewPublicGroup
Creates a command with all Option parameters set to None and all bool parameters set to false