pub struct ApiSetActiveUser {
pub user_id: i64,
pub view_pwd: Option<String>,
}Expand description
User profile commands
Most bots don’t need to use these commands, as bot profile can be configured manually via CLI or desktop client. These commands can be used by bots that need to manage multiple user profiles (e.g., the profiles of support agents).
Set active user profile.
Network usage: no.
Syntax:
/_user <userId>[ <json(viewPwd)>]Fields
user_id: i64view_pwd: Option<String>Implementations
Sourceimpl ApiSetActiveUser
impl ApiSetActiveUser
Sourcepub fn builder() -> ApiSetActiveUserBuilder
pub fn builder() -> ApiSetActiveUserBuilder
Create an instance of ApiSetActiveUser using the builder syntax
Sourceimpl ApiSetActiveUser
impl ApiSetActiveUser
Sourcepub fn new(user_id: i64) -> ApiSetActiveUser
pub fn new(user_id: i64) -> ApiSetActiveUser
Creates a command with all Option parameters set to None and all bool parameters set to false