pub struct ApiSetContactCustomData {
pub contact_id: i64,
pub custom_data: Option<Value>,
}Expand description
Chat commands
Commands to list and delete conversations.
Set contact custom data.
Network usage: no.
Syntax:
/_set custom @<contactId>[ <json(customData)>]Fields
contact_id: i64custom_data: Option<Value>Implementations
Sourceimpl ApiSetContactCustomData
impl ApiSetContactCustomData
Sourcepub fn builder() -> ApiSetContactCustomDataBuilder
pub fn builder() -> ApiSetContactCustomDataBuilder
Create an instance of ApiSetContactCustomData using the builder syntax
Sourceimpl ApiSetContactCustomData
impl ApiSetContactCustomData
Sourcepub fn new(contact_id: i64) -> ApiSetContactCustomData
pub fn new(contact_id: i64) -> ApiSetContactCustomData
Creates a command with all Option parameters set to None and all bool parameters set to false