pub struct ApiSetGroupCustomData {
pub group_id: i64,
pub custom_data: Option<Value>,
}Expand description
Chat commands
Commands to list and delete conversations.
Set group custom data.
Network usage: no.
Syntax:
/_set custom #<groupId>[ <json(customData)>]Fields
group_id: i64custom_data: Option<Value>Implementations
Sourceimpl ApiSetGroupCustomData
impl ApiSetGroupCustomData
Sourcepub fn new(group_id: i64) -> ApiSetGroupCustomData
pub fn new(group_id: i64) -> ApiSetGroupCustomData
Creates a command with all Option parameters set to None and all bool parameters set to false