pub struct ApiSetProfileAddress {
pub user_id: i64,
pub enable: bool,
}Expand description
Address commands
Bots can use these commands to automatically check and create address when initialized
Add address to bot profile.
Network usage: interactive.
Syntax:
/_profile_address <userId> on|offFields
user_id: i64enable: boolImplementations
Sourceimpl ApiSetProfileAddress
impl ApiSetProfileAddress
Sourcepub fn builder() -> ApiSetProfileAddressBuilder
pub fn builder() -> ApiSetProfileAddressBuilder
Create an instance of ApiSetProfileAddress using the builder syntax
Sourceimpl ApiSetProfileAddress
impl ApiSetProfileAddress
Sourcepub fn new(user_id: i64) -> ApiSetProfileAddress
pub fn new(user_id: i64) -> ApiSetProfileAddress
Creates a command with all Option parameters set to None and all bool parameters set to false