pub struct CreateActiveUser {
pub new_user: NewUser,
}Expand description
User profile commands
Most bots don’t need to use these commands, as bot profile can be configured manually via CLI or desktop client. These commands can be used by bots that need to manage multiple user profiles (e.g., the profiles of support agents).
Create new user profile.
Network usage: no.
Syntax:
/_create user <json(newUser)>Fields
new_user: NewUserImplementations
Sourceimpl CreateActiveUser
impl CreateActiveUser
Sourcepub fn builder() -> CreateActiveUserBuilder
pub fn builder() -> CreateActiveUserBuilder
Create an instance of CreateActiveUser using the builder syntax