pub struct ListUsers {}Expand description
User profile commands
Most bots don’t need to use these commands, as bot profile can be configured manually via CLI or desktop client. These commands can be used by bots that need to manage multiple user profiles (e.g., the profiles of support agents).
Get all user profiles.
Network usage: no.
Syntax:
/usersImplementations