pub struct EncryptedFile<S: SimplexSecretBox> { /* private fields */ }crypto only.Expand description
Async wrapper over a file with SimpleX-SecretBox encryption.
Security
-
All bytes returned from
read()are unauthenticated until the file is fully read. The caller must never act on streamed content untilread()has returnedOk(0). If reading a file returns Err() all previously read data cannot be trusted and must be discarded. -
The caller is responsible to call
Self::put_auth_tagmanually. TheAsyncWriteimplementation does its best to write the authentication tag but it can silently fail leaving the file unauthenticated.
Implementations
Sourceimpl<S: SimplexSecretBox> EncryptedFile<S>
impl<S: SimplexSecretBox> EncryptedFile<S>
pub async fn create<P: AsRef<Path>>(path: P) -> Result<Self>
pub async fn create_with_args<P: AsRef<Path>>( path: P, crypto_args: FileCryptoArgs, ) -> Result<Self>
Sourcepub async fn open<P: AsRef<Path>>(
path: P,
crypto_args: FileCryptoArgs,
) -> Result<Self>
pub async fn open<P: AsRef<Path>>( path: P, crypto_args: FileCryptoArgs, ) -> Result<Self>
Note: this call requires write permissions on the file system for
Self::prepare_for_overwrite to work. Use Self::open_read_only when write access is
not needed or not available.
Sourcepub async fn open_read_only<P: AsRef<Path>>(
path: P,
crypto_args: FileCryptoArgs,
) -> Result<Self>
pub async fn open_read_only<P: AsRef<Path>>( path: P, crypto_args: FileCryptoArgs, ) -> Result<Self>
Opens file in a read-only mode. Self::prepare_for_overwrite will return an IO error.
pub async fn prepare_for_overwrite(&mut self) -> Result<()>
pub fn crypto_args(&self) -> &FileCryptoArgs
pub fn optimal_buf_size(&self) -> usize
pub fn plaintext_size_hint(&self) -> usize
Sourcepub async fn put_auth_tag(self) -> Result<()>
pub async fn put_auth_tag(self) -> Result<()>
Does nothing if auth tag was already written