Module events

Module events 

Structs

AcceptingBusinessRequest
Connection progress events
AcceptingBusinessRequestBuilder
Use builder syntax to set the inputs and finish with build().
AcceptingContactRequest
Connection progress events
AcceptingContactRequestBuilder
Use builder syntax to set the inputs and finish with build().
BusinessLinkConnecting
Connection progress events
BusinessLinkConnectingBuilder
Use builder syntax to set the inputs and finish with build().
ChatError
Error events
ChatErrorBuilder
Use builder syntax to set the inputs and finish with build().
ChatErrors
Error events
ChatErrorsBuilder
Use builder syntax to set the inputs and finish with build().
ChatItemReaction
Message events
ChatItemReactionBuilder
Use builder syntax to set the inputs and finish with build().
ChatItemUpdated
Message events
ChatItemUpdatedBuilder
Use builder syntax to set the inputs and finish with build().
ChatItemsDeleted
Message events
ChatItemsDeletedBuilder
Use builder syntax to set the inputs and finish with build().
ChatItemsStatusesUpdated
Message events
ChatItemsStatusesUpdatedBuilder
Use builder syntax to set the inputs and finish with build().
ConnectedToGroupMember
Group events
ConnectedToGroupMemberBuilder
Use builder syntax to set the inputs and finish with build().
ContactConnected
Contact connection events
ContactConnectedBuilder
Use builder syntax to set the inputs and finish with build().
ContactConnecting
Connection progress events
ContactConnectingBuilder
Use builder syntax to set the inputs and finish with build().
ContactDeletedByContact
Contact connection events
ContactDeletedByContactBuilder
Use builder syntax to set the inputs and finish with build().
ContactSndReady
Contact connection events
ContactSndReadyBuilder
Use builder syntax to set the inputs and finish with build().
ContactUpdated
Contact connection events
ContactUpdatedBuilder
Use builder syntax to set the inputs and finish with build().
DeletedMember
Group events
DeletedMemberBuilder
Use builder syntax to set the inputs and finish with build().
DeletedMemberUser
Group events
DeletedMemberUserBuilder
Use builder syntax to set the inputs and finish with build().
GroupChatItemsDeleted
Message events
GroupChatItemsDeletedBuilder
Use builder syntax to set the inputs and finish with build().
GroupDeleted
Group events
GroupDeletedBuilder
Use builder syntax to set the inputs and finish with build().
GroupLinkConnecting
Connection progress events
GroupLinkConnectingBuilder
Use builder syntax to set the inputs and finish with build().
GroupLinkDataUpdated
Group events
GroupLinkDataUpdatedBuilder
Use builder syntax to set the inputs and finish with build().
GroupMemberUpdated
Group events
GroupMemberUpdatedBuilder
Use builder syntax to set the inputs and finish with build().
GroupRelayUpdated
Group events
GroupRelayUpdatedBuilder
Use builder syntax to set the inputs and finish with build().
GroupUpdated
Group events
GroupUpdatedBuilder
Use builder syntax to set the inputs and finish with build().
HostConnected
Network connection events
HostConnectedBuilder
Use builder syntax to set the inputs and finish with build().
HostDisconnected
Network connection events
HostDisconnectedBuilder
Use builder syntax to set the inputs and finish with build().
JoinedGroupMember
Group events
JoinedGroupMemberBuilder
Use builder syntax to set the inputs and finish with build().
JoinedGroupMemberConnecting
Connection progress events
JoinedGroupMemberConnectingBuilder
Use builder syntax to set the inputs and finish with build().
LeftMember
Group events
LeftMemberBuilder
Use builder syntax to set the inputs and finish with build().
MemberAcceptedByOther
Group events
MemberAcceptedByOtherBuilder
Use builder syntax to set the inputs and finish with build().
MemberBlockedForAll
Group events
MemberBlockedForAllBuilder
Use builder syntax to set the inputs and finish with build().
MemberRole
Group events
MemberRoleBuilder
Use builder syntax to set the inputs and finish with build().
MessageError
Error events
MessageErrorBuilder
Use builder syntax to set the inputs and finish with build().
NewChatItems
Message events
NewChatItemsBuilder
Use builder syntax to set the inputs and finish with build().
NewMemberContactReceivedInv
Contact connection events
NewMemberContactReceivedInvBuilder
Use builder syntax to set the inputs and finish with build().
RcvFileAccepted
File events
RcvFileAcceptedBuilder
Use builder syntax to set the inputs and finish with build().
RcvFileComplete
File events
RcvFileCompleteBuilder
Use builder syntax to set the inputs and finish with build().
RcvFileDescrReady
File events
RcvFileDescrReadyBuilder
Use builder syntax to set the inputs and finish with build().
RcvFileError
File events
RcvFileErrorBuilder
Use builder syntax to set the inputs and finish with build().
RcvFileSndCancelled
File events
RcvFileSndCancelledBuilder
Use builder syntax to set the inputs and finish with build().
RcvFileStart
File events
RcvFileStartBuilder
Use builder syntax to set the inputs and finish with build().
RcvFileWarning
File events
RcvFileWarningBuilder
Use builder syntax to set the inputs and finish with build().
ReceivedContactRequest
Contact connection events
ReceivedContactRequestBuilder
Use builder syntax to set the inputs and finish with build().
ReceivedGroupInvitation
Group events
ReceivedGroupInvitationBuilder
Use builder syntax to set the inputs and finish with build().
SentGroupInvitation
Connection progress events
SentGroupInvitationBuilder
Use builder syntax to set the inputs and finish with build().
SndFileCompleteXftp
File events
SndFileCompleteXftpBuilder
Use builder syntax to set the inputs and finish with build().
SndFileError
File events
SndFileErrorBuilder
Use builder syntax to set the inputs and finish with build().
SndFileWarning
File events
SndFileWarningBuilder
Use builder syntax to set the inputs and finish with build().
SubscriptionStatus
Network connection events
SubscriptionStatusBuilder
Use builder syntax to set the inputs and finish with build().
UserJoinedGroup
Group events
UserJoinedGroupBuilder
Use builder syntax to set the inputs and finish with build().

Enums

Event
EventKind

Traits

EventData
Generalization of event data