pub struct ContactUpdated {
pub user: User,
pub from_contact: Contact,
pub to_contact: Contact,
pub undocumented: Value,
}Expand description
Contact connection events
Bots must use these events to process connecting users.
Most bots enable auto-accept and don’t need to accept connections via commands.
You may create bot SimpleX address manually via CLI or desktop app or from bot code with these commands:
- ApiShowMyAddress to check if address exists,
- ApiCreateMyAddress to create address,
- ApiSetAddressSettings to enable auto-access.
Contact profile of another user is updated.
Fields
user: Userfrom_contact: Contactto_contact: Contactundocumented: ValueImplementations
Sourceimpl ContactUpdated
impl ContactUpdated
Sourcepub fn builder() -> ContactUpdatedBuilder
pub fn builder() -> ContactUpdatedBuilder
Create an instance of ContactUpdated using the builder syntax