RcvFileError

Struct RcvFileError 

pub struct RcvFileError {
    pub user: User,
    pub chat_item: Option<AChatItem>,
    pub agent_error: AgentErrorType,
    pub rcv_file_transfer: RcvFileTransfer,
    pub undocumented: Value,
}
File events

Bots that send or receive files may process these events to track delivery status and to process completion.

Bots that need to receive or moderate files (e.g., based on name, size or extension), can use relevant commands (e.g., ReceiveFile or ApiDeleteMemberChatItem) when processing NewChatItems event.

Bots that need to send files should use ApiSendMessages command.


Error receiving file.

Fields

user: Userchat_item: Option<AChatItem>agent_error: AgentErrorTypercv_file_transfer: RcvFileTransferundocumented: Value

Implementations

Source

impl RcvFileError

pub fn builder() -> RcvFileErrorBuilder

Create an instance of RcvFileError using the builder syntax