pub struct RcvFileWarning {
pub user: User,
pub chat_item: Option<AChatItem>,
pub agent_error: AgentErrorType,
pub rcv_file_transfer: RcvFileTransfer,
pub undocumented: Value,
}Expand description
File events
Bots that send or receive files may process these events to track delivery status and to process completion.
Bots that need to receive or moderate files (e.g., based on name, size or extension), can use relevant commands (e.g., ReceiveFile or ApiDeleteMemberChatItem) when processing NewChatItems event.
Bots that need to send files should use ApiSendMessages command.
Warning when receiving file. It can happen when CLI settings do not allow to connect to file server(s).
Fields
user: Userchat_item: Option<AChatItem>agent_error: AgentErrorTypercv_file_transfer: RcvFileTransferundocumented: ValueImplementations
Sourceimpl RcvFileWarning
impl RcvFileWarning
Sourcepub fn builder() -> RcvFileWarningBuilder
pub fn builder() -> RcvFileWarningBuilder
Create an instance of RcvFileWarning using the builder syntax