pub struct ReceivedContactRequest {
pub user: User,
pub contact_request: UserContactRequest,
pub chat: Option<AChat>,
pub undocumented: Value,
}Expand description
Contact connection events
Bots must use these events to process connecting users.
Most bots enable auto-accept and don’t need to accept connections via commands.
You may create bot SimpleX address manually via CLI or desktop app or from bot code with these commands:
- ApiShowMyAddress to check if address exists,
- ApiCreateMyAddress to create address,
- ApiSetAddressSettings to enable auto-access.
Contact request received.
This event is only sent when auto-accept is disabled.
The request needs to be accepted using ApiAcceptContact command
Fields
user: Usercontact_request: UserContactRequestchat: Option<AChat>undocumented: ValueImplementations
Sourceimpl ReceivedContactRequest
impl ReceivedContactRequest
Sourcepub fn builder() -> ReceivedContactRequestBuilder
pub fn builder() -> ReceivedContactRequestBuilder
Create an instance of ReceivedContactRequest using the builder syntax