pub struct SndFileCompleteXftp {
pub user: User,
pub chat_item: AChatItem,
pub file_transfer_meta: FileTransferMeta,
pub undocumented: Value,
}Expand description
File events
Bots that send or receive files may process these events to track delivery status and to process completion.
Bots that need to receive or moderate files (e.g., based on name, size or extension), can use relevant commands (e.g., ReceiveFile or ApiDeleteMemberChatItem) when processing NewChatItems event.
Bots that need to send files should use ApiSendMessages command.
File upload is competed.
Fields
user: Userchat_item: AChatItemfile_transfer_meta: FileTransferMetaundocumented: ValueImplementations
Sourceimpl SndFileCompleteXftp
impl SndFileCompleteXftp
Sourcepub fn builder() -> SndFileCompleteXftpBuilder
pub fn builder() -> SndFileCompleteXftpBuilder
Create an instance of SndFileCompleteXftp using the builder syntax