Module ffi

Module ffi 

Available on crate feature ffi only.
FFI backend that embeds the SimpleX-Chat library in-process via native Rust bindings.

Use BotBuilder to initialise the FFI runtime and get a ready-to-use Bot. For lower-level access, init and init_with_config return a Client and an EventStream directly.

Requires AGPL-3.0 and additional build configuration. See simploxide-sxcrt-sys.

Structs

BotBuilder
Builder for an FFI-backed Bot.
BotFarmBuilderfarm
Client
A cheaply clonable high-level FFI client implementing ClientApi
DbOpts
Database options for a SimpleX chat instance.
DefaultUser
The SimpleX user profile used to initialise the chat instance.
RawClient
A lightweight cheaply clonable client for sending raw requests(SimpleX commands) and receiving raw responses(JSON objects).
SimplexVersion
Parses SimpleX version numbers in the form MAJOR.MINOR.PATCH.HOTFIX.
WorkerConfig
Configuration for the shared FFI worker thread.

Enums

BotInitError
Error returned by BotBuilder::launch.
CallError
ClientError
See crate::client_api::AllowUndocumentedResponses if you don’t want to trigger an error when you receive undocumeted responses(you usually receive undocumented responses when your simplex-chat version is not compatible with the current simploxide-client version. Keep an eye on the Version compatability table)
CoreInitError
InitError
VersionError
Error returned by RawClient::version.

Functions

init
init_with_config

Type Aliases

Botxftp
ClientResult
CoreEvent
CoreResult
EventResult
EventStream
FarmBotfarm
InitFarmfarm
RunningFarmfarm