BotBuilder

Struct BotBuilder 

pub struct BotBuilder { /* private fields */ }
Available on crate feature ffi only.
Builder for an FFI-backed Bot.

Implementations

Source

impl BotBuilder

pub fn new(name: impl Into<BotName>, db_opts: DbOpts) -> Self

Build a bot account (default).

pub fn with_default_user(self, user: DefaultUser) -> Self

Override the default user created for empty databases.

By default the default user name matches the bot name. This setting allows to create default user different from an active bot

pub fn auto_accept(self) -> Self

Create public address and auto accept users

pub fn auto_accept_with(self, welcome_message: impl Into<String>) -> Self

Self::auto_accept with a welcome message

pub fn with_avatar(self, avatar: ImagePreview) -> Self

Set the bot avatar during initialisation

pub fn with_bio(self, bio: impl Into<String>) -> Self

Set the bot bio (short_descr) during initialisation. Ignored when Self::with_profile is also set.

pub fn with_description(self, description: impl Into<String>) -> Self

Set the bot description during initialisation. Ignored when Self::with_profile is also set.

pub fn with_profile(self, profile: Profile) -> Self

Update/create the whole bot profile on launch

pub fn with_preferences(self, prefs: Preferences) -> Self

Apply these preferences to the bot’s profile during initialisation.

pub fn with_worker_config(self, config: WorkerConfig) -> Self

Override FFI worker thread settings. See WorkerConfig for available options.

pub async fn launch(self) -> Result<(Bot, EventStream), BotInitError>

Initialise the SimpleX FFI runtime and return a ready-to-use bot.