pub struct BotFarmBuilder { /* private fields */ }Available on crate features
farm and ffi only.Implementations
Sourceimpl BotFarmBuilder
impl BotFarmBuilder
pub fn new(name: impl Into<String>, db_opts: DbOpts) -> Self
Sourcepub fn with_default_user(self, user: DefaultUser) -> Self
pub fn with_default_user(self, user: DefaultUser) -> Self
Override the default user created for empty databases.
By default the default user name matches the bot name. This setting allows to create a user different from an active bot
Sourcepub fn max_event_latency(self, latency: Duration) -> Self
pub fn max_event_latency(self, latency: Duration) -> Self
Set max permissible event latency. See WorkerConfig::max_event_latency for details
Sourcepub fn max_instances(self, instances: usize) -> Self
pub fn max_instances(self, instances: usize) -> Self
Set max concurrent SimpleX-Chat instances. See WorkerConfig::max_instances for details
Sourcepub async fn launch(
self,
) -> Result<BotFarm<Init<Client, CoreResult<CoreEvent>>>, BotInitError>
pub async fn launch( self, ) -> Result<BotFarm<Init<Client, CoreResult<CoreEvent>>>, BotInitError>
Initialise the SimpleX FFI runtime and return a farm