pub struct ApiAddGroupRelays {
pub group_id: i64,
pub relay_ids: Vec<i64>,
}Expand description
Group commands
Commands to manage and moderate groups. These commands can be used with business chats as well - they are groups. E.g., a common scenario would be to add human agents to business chat with the customer who connected via business address.
Add relays to group.
Network usage: interactive.
Syntax:
/_add relays #<groupId> <relayIds[0]>[,<relayIds[1]>...]Fields
group_id: i64relay_ids: Vec<i64>Implementations
Sourceimpl ApiAddGroupRelays
impl ApiAddGroupRelays
Sourcepub fn builder() -> ApiAddGroupRelaysBuilder
pub fn builder() -> ApiAddGroupRelaysBuilder
Create an instance of ApiAddGroupRelays using the builder syntax