pub struct ApiDeleteUser {
pub user_id: i64,
pub del_smp_queues: bool,
pub view_pwd: Option<String>,
}Expand description
User profile commands
Most bots don’t need to use these commands, as bot profile can be configured manually via CLI or desktop client. These commands can be used by bots that need to manage multiple user profiles (e.g., the profiles of support agents).
Delete user profile.
Network usage: background.
Syntax:
/_delete user <userId> del_smp=on|off[ <json(viewPwd)>]Fields
user_id: i64del_smp_queues: boolview_pwd: Option<String>Implementations
Sourceimpl ApiDeleteUser
impl ApiDeleteUser
Sourcepub fn builder() -> ApiDeleteUserBuilder
pub fn builder() -> ApiDeleteUserBuilder
Create an instance of ApiDeleteUser using the builder syntax
Sourceimpl ApiDeleteUser
impl ApiDeleteUser
Sourcepub fn new(user_id: i64) -> ApiDeleteUser
pub fn new(user_id: i64) -> ApiDeleteUser
Creates a command with all Option parameters set to None and all bool parameters set to false