pub struct ApiJoinGroup {
pub group_id: i64,
}Expand description
Group commands
Commands to manage and moderate groups. These commands can be used with business chats as well - they are groups. E.g., a common scenario would be to add human agents to business chat with the customer who connected via business address.
Join group.
Network usage: interactive.
Syntax:
/_join #<groupId>Fields
group_id: i64Implementations
Sourceimpl ApiJoinGroup
impl ApiJoinGroup
Sourcepub fn builder() -> ApiJoinGroupBuilder
pub fn builder() -> ApiJoinGroupBuilder
Create an instance of ApiJoinGroup using the builder syntax