pub struct ApiLeaveGroup {
pub group_id: i64,
}Expand description
Group commands
Commands to manage and moderate groups. These commands can be used with business chats as well - they are groups. E.g., a common scenario would be to add human agents to business chat with the customer who connected via business address.
Leave group.
Network usage: background.
Syntax:
/_leave #<groupId>Fields
group_id: i64Implementations
Sourceimpl ApiLeaveGroup
impl ApiLeaveGroup
Sourcepub fn builder() -> ApiLeaveGroupBuilder
pub fn builder() -> ApiLeaveGroupBuilder
Create an instance of ApiLeaveGroup using the builder syntax