pub struct ApiSetContactPrefs {
pub contact_id: i64,
pub preferences: Preferences,
}Expand description
User profile commands
Most bots don’t need to use these commands, as bot profile can be configured manually via CLI or desktop client. These commands can be used by bots that need to manage multiple user profiles (e.g., the profiles of support agents).
Configure chat preference overrides for the contact.
Network usage: background.
Syntax:
/_set prefs @<contactId> <json(preferences)>Fields
contact_id: i64preferences: PreferencesImplementations
Sourceimpl ApiSetContactPrefs
impl ApiSetContactPrefs
Sourcepub fn builder() -> ApiSetContactPrefsBuilder
pub fn builder() -> ApiSetContactPrefsBuilder
Create an instance of ApiSetContactPrefs using the builder syntax