pub struct ApiSetUserAutoAcceptMemberContacts {
pub user_id: i64,
pub on_off: bool,
}Expand description
Chat commands
Commands to list and delete conversations.
Set auto-accept member contacts.
Network usage: no.
Syntax:
/_set accept member contacts <userId> on|offFields
user_id: i64on_off: boolImplementations
Sourceimpl ApiSetUserAutoAcceptMemberContacts
impl ApiSetUserAutoAcceptMemberContacts
Sourcepub fn new(user_id: i64) -> ApiSetUserAutoAcceptMemberContacts
pub fn new(user_id: i64) -> ApiSetUserAutoAcceptMemberContacts
Creates a command with all Option parameters set to None and all bool parameters set to false