pub struct RcvFileComplete {
pub user: User,
pub chat_item: AChatItem,
pub undocumented: Value,
}Expand description
File events
Bots that send or receive files may process these events to track delivery status and to process completion.
Bots that need to receive or moderate files (e.g., based on name, size or extension), can use relevant commands (e.g., ReceiveFile or ApiDeleteMemberChatItem) when processing NewChatItems event.
Bots that need to send files should use ApiSendMessages command.
File reception is competed.
Fields
user: Userchat_item: AChatItemundocumented: ValueImplementations
Sourceimpl RcvFileComplete
impl RcvFileComplete
Sourcepub fn builder() -> RcvFileCompleteBuilder
pub fn builder() -> RcvFileCompleteBuilder
Create an instance of RcvFileComplete using the builder syntax