Module responses

Module responses 

Structs

AcceptingContactRequestResponse
AcceptingContactRequestResponseBuilder
Use builder syntax to set the inputs and finish with build().
ActiveUserResponse
ActiveUserResponseBuilder
Use builder syntax to set the inputs and finish with build().
ApiChatsResponse
ApiChatsResponseBuilder
Use builder syntax to set the inputs and finish with build().
ChatCmdErrorResponse
ChatCmdErrorResponseBuilder
Use builder syntax to set the inputs and finish with build().
ChatItemNotChangedResponse
ChatItemNotChangedResponseBuilder
Use builder syntax to set the inputs and finish with build().
ChatItemReactionResponse
ChatItemReactionResponseBuilder
Use builder syntax to set the inputs and finish with build().
ChatItemUpdatedResponse
ChatItemUpdatedResponseBuilder
Use builder syntax to set the inputs and finish with build().
ChatItemsDeletedResponse
ChatItemsDeletedResponseBuilder
Use builder syntax to set the inputs and finish with build().
ChatRunningResponse
ChatRunningResponseBuilder
Use builder syntax to set the inputs and finish with build().
ChatStartedResponse
ChatStartedResponseBuilder
Use builder syntax to set the inputs and finish with build().
ChatStoppedResponse
ChatStoppedResponseBuilder
Use builder syntax to set the inputs and finish with build().
CmdOkResponse
CmdOkResponseBuilder
Use builder syntax to set the inputs and finish with build().
ConnectionPlanResponse
ConnectionPlanResponseBuilder
Use builder syntax to set the inputs and finish with build().
ContactAlreadyExistsResponse
ContactAlreadyExistsResponseBuilder
Use builder syntax to set the inputs and finish with build().
ContactConnectionDeletedResponse
ContactConnectionDeletedResponseBuilder
Use builder syntax to set the inputs and finish with build().
ContactDeletedResponse
ContactDeletedResponseBuilder
Use builder syntax to set the inputs and finish with build().
ContactPrefsUpdatedResponse
ContactPrefsUpdatedResponseBuilder
Use builder syntax to set the inputs and finish with build().
ContactRequestRejectedResponse
ContactRequestRejectedResponseBuilder
Use builder syntax to set the inputs and finish with build().
ContactsListResponse
ContactsListResponseBuilder
Use builder syntax to set the inputs and finish with build().
GroupCreatedResponse
GroupCreatedResponseBuilder
Use builder syntax to set the inputs and finish with build().
GroupDeletedUserResponse
GroupDeletedUserResponseBuilder
Use builder syntax to set the inputs and finish with build().
GroupLinkCreatedResponse
GroupLinkCreatedResponseBuilder
Use builder syntax to set the inputs and finish with build().
GroupLinkDeletedResponse
GroupLinkDeletedResponseBuilder
Use builder syntax to set the inputs and finish with build().
GroupLinkResponse
GroupLinkResponseBuilder
Use builder syntax to set the inputs and finish with build().
GroupMembersResponse
GroupMembersResponseBuilder
Use builder syntax to set the inputs and finish with build().
GroupRelaysAddFailedResponse
GroupRelaysAddFailedResponseBuilder
Use builder syntax to set the inputs and finish with build().
GroupRelaysAddedResponse
GroupRelaysAddedResponseBuilder
Use builder syntax to set the inputs and finish with build().
GroupRelaysResponse
GroupRelaysResponseBuilder
Use builder syntax to set the inputs and finish with build().
GroupUpdatedResponse
GroupUpdatedResponseBuilder
Use builder syntax to set the inputs and finish with build().
GroupsListResponse
GroupsListResponseBuilder
Use builder syntax to set the inputs and finish with build().
InvitationResponse
InvitationResponseBuilder
Use builder syntax to set the inputs and finish with build().
LeftMemberUserResponse
LeftMemberUserResponseBuilder
Use builder syntax to set the inputs and finish with build().
MemberAcceptedResponse
MemberAcceptedResponseBuilder
Use builder syntax to set the inputs and finish with build().
MembersBlockedForAllUserResponse
MembersBlockedForAllUserResponseBuilder
Use builder syntax to set the inputs and finish with build().
MembersRoleUserResponse
MembersRoleUserResponseBuilder
Use builder syntax to set the inputs and finish with build().
NewChatItemsResponse
NewChatItemsResponseBuilder
Use builder syntax to set the inputs and finish with build().
PublicGroupCreatedResponse
PublicGroupCreatedResponseBuilder
Use builder syntax to set the inputs and finish with build().
PublicGroupCreationFailedResponse
PublicGroupCreationFailedResponseBuilder
Use builder syntax to set the inputs and finish with build().
RcvFileAcceptedResponse
RcvFileAcceptedResponseBuilder
Use builder syntax to set the inputs and finish with build().
RcvFileAcceptedSndCancelledResponse
RcvFileAcceptedSndCancelledResponseBuilder
Use builder syntax to set the inputs and finish with build().
RcvFileCancelledResponse
RcvFileCancelledResponseBuilder
Use builder syntax to set the inputs and finish with build().
SentConfirmationResponse
SentConfirmationResponseBuilder
Use builder syntax to set the inputs and finish with build().
SentGroupInvitationResponse
SentGroupInvitationResponseBuilder
Use builder syntax to set the inputs and finish with build().
SentInvitationResponse
SentInvitationResponseBuilder
Use builder syntax to set the inputs and finish with build().
SndFileCancelledResponse
SndFileCancelledResponseBuilder
Use builder syntax to set the inputs and finish with build().
UserAcceptedGroupSentResponse
UserAcceptedGroupSentResponseBuilder
Use builder syntax to set the inputs and finish with build().
UserContactLinkCreatedResponse
UserContactLinkCreatedResponseBuilder
Use builder syntax to set the inputs and finish with build().
UserContactLinkDeletedResponse
UserContactLinkDeletedResponseBuilder
Use builder syntax to set the inputs and finish with build().
UserContactLinkResponse
UserContactLinkResponseBuilder
Use builder syntax to set the inputs and finish with build().
UserContactLinkUpdatedResponse
UserContactLinkUpdatedResponseBuilder
Use builder syntax to set the inputs and finish with build().
UserDeletedMembersResponse
UserDeletedMembersResponseBuilder
Use builder syntax to set the inputs and finish with build().
UserProfileNoChangeResponse
UserProfileNoChangeResponseBuilder
Use builder syntax to set the inputs and finish with build().
UserProfileUpdatedResponse
UserProfileUpdatedResponseBuilder
Use builder syntax to set the inputs and finish with build().
UsersListResponse
UsersListResponseBuilder
Use builder syntax to set the inputs and finish with build().

Enums

ApiAcceptContactResponse
ApiAcceptMemberResponse
ApiAddContactResponse
ApiAddGroupRelaysResponse
ApiAddMemberResponse
ApiBlockMembersForAllResponse
ApiChatItemReactionResponse
ApiConnectPlanResponse
ApiConnectResponse
ApiCreateGroupLinkResponse
ApiCreateMyAddressResponse
ApiDeleteChatItemResponse
ApiDeleteChatResponse
ApiDeleteGroupLinkResponse
ApiDeleteMemberChatItemResponse
ApiDeleteMyAddressResponse
ApiDeleteUserResponse
ApiGetChatsResponse
ApiGetGroupLinkResponse
ApiGetGroupRelaysResponse
ApiGroupLinkMemberRoleResponse
ApiJoinGroupResponse
ApiLeaveGroupResponse
ApiListContactsResponse
ApiListGroupsResponse
ApiListMembersResponse
ApiMembersRoleResponse
ApiNewGroupResponse
ApiNewPublicGroupResponse
ApiRejectContactResponse
ApiRemoveMembersResponse
ApiSendMessagesResponse
ApiSetActiveUserResponse
ApiSetAddressSettingsResponse
ApiSetContactCustomDataResponse
ApiSetContactPrefsResponse
ApiSetGroupCustomDataResponse
ApiSetProfileAddressResponse
ApiSetUserAutoAcceptMemberContactsResponse
ApiShowMyAddressResponse
ApiStopChatResponse
ApiUpdateChatItemResponse
ApiUpdateGroupProfileResponse
ApiUpdateProfileResponse
CancelFileResponse
ChatCmdError
ConnectResponse
CreateActiveUserResponse
ListUsersResponse
ReceiveFileResponse
ShowActiveUserResponse
StartChatResponse