pub enum ClientError {
WebSocketFailure(CoreError),
BadResponse(BadResponseError),
}Available on crate feature
websocket only.Expand description
See crate::client_api::AllowUndocumentedResponses if you don’t want to trigger an error when
you receive undocumeted responses(you usually receive undocumented responses when your
simplex-chat server version is not compatible with the simploxide-client version. Keep an eye
on the
Version compatability table
)
Variants
WebSocketFailure(CoreError)
Critical error signalling that the web socket connection is dropped for some reason. You will have to reconnect to the SimpleX server to recover from this one.
BadResponse(BadResponseError)
SimpleX command error or unexpected(undocumented) response.