Client

Struct Client 

pub struct Client { /* private fields */ }
Available on crate feature websocket only.
A high level SimpleX-Chat client which provides typed API methods with automatic command serialization and response deserialization.

Implementations

Source

impl Client

pub fn version( &self, ) -> impl Future<Output = Result<SimplexVersion, VersionError>>

pub fn disconnect(self) -> impl Future<Output = ()>

Initiates a graceful shutdown for the underlying web socket connection. See simploxide_ws_core::RawClient::disconnect for details.