pub enum DownloadError<E> {
SendCancelled(Arc<RcvFileSndCancelled>),
AcceptCancelled(Arc<RcvFileAcceptedSndCancelledResponse>),
Receive(Arc<RcvFileError>),
Api(E),
}Available on crate feature
xftp only.Expand description
Error returned when a DownloadFileBuilder future resolves unsuccessfully.
Variants
SendCancelled(Arc<RcvFileSndCancelled>)
The sender cancelled the transfer after the download was accepted.
AcceptCancelled(Arc<RcvFileAcceptedSndCancelledResponse>)
The file was no longer available when the download request arrived.
Receive(Arc<RcvFileError>)
The SimpleX agent reported an error while receiving the file.
Api(E)
The API call to initiate the download failed.