pub struct XftpClient<C> { /* private fields */ }Available on crate feature
xftp only.Expand description
A ClientApi wrapper that intercepts file-result events and routes them to the
corresponding DownloadFileBuilder futures. Should be constructed by
EventStream::hook_xftp to work correctly.
Implementations
Sourceimpl XftpClient<Client>
impl XftpClient<Client>
pub fn disconnect(self) -> impl Future<Output = ()>
Available on crate feature
websocket only.Sourceimpl XftpClient<Client>
impl XftpClient<Client>
pub fn disconnect(self) -> impl Future<Output = ()>
Available on crate feature
ffi only.Trait Implementations
Sourceimpl<C: ClientApi> ClientApi for XftpClient<C>
impl<C: ClientApi> ClientApi for XftpClient<C>
type ResponseShape<'de, T: 'de + Deserialize<'de>> = <C as ClientApi>::ResponseShape<'de, T>
type Error = <C as ClientApi>::Error
fn send_raw( &self, command: String, ) -> impl Future<Output = Result<String, Self::Error>> + Send
Sourcefn cancel_file(
&self,
file_id: i64,
) -> impl Future<Output = Result<CancelFileResponse, Self::Error>> + Send
fn cancel_file( &self, file_id: i64, ) -> impl Future<Output = Result<CancelFileResponse, Self::Error>> + Send
File commands Read more
fn send<C, R>( &self, cmd: C, ) -> impl Future<Output = Result<R, Self::Error>> + Send
Sourcefn api_create_my_address(
&self,
user_id: i64,
) -> impl Future<Output = Result<Arc<UserContactLinkCreatedResponse>, Self::Error>> + Send
fn api_create_my_address( &self, user_id: i64, ) -> impl Future<Output = Result<Arc<UserContactLinkCreatedResponse>, Self::Error>> + Send
Address commands Read more
Sourcefn api_delete_my_address(
&self,
user_id: i64,
) -> impl Future<Output = Result<Arc<UserContactLinkDeletedResponse>, Self::Error>> + Send
fn api_delete_my_address( &self, user_id: i64, ) -> impl Future<Output = Result<Arc<UserContactLinkDeletedResponse>, Self::Error>> + Send
Address commands Read more
Sourcefn api_show_my_address(
&self,
user_id: i64,
) -> impl Future<Output = Result<Arc<UserContactLinkResponse>, Self::Error>> + Send
fn api_show_my_address( &self, user_id: i64, ) -> impl Future<Output = Result<Arc<UserContactLinkResponse>, Self::Error>> + Send
Address commands Read more
Sourcefn api_set_profile_address(
&self,
command: ApiSetProfileAddress,
) -> impl Future<Output = Result<Arc<UserProfileUpdatedResponse>, Self::Error>> + Send
fn api_set_profile_address( &self, command: ApiSetProfileAddress, ) -> impl Future<Output = Result<Arc<UserProfileUpdatedResponse>, Self::Error>> + Send
Address commands Read more
Sourcefn api_set_address_settings(
&self,
user_id: i64,
settings: AddressSettings,
) -> impl Future<Output = Result<Arc<UserContactLinkUpdatedResponse>, Self::Error>> + Send
fn api_set_address_settings( &self, user_id: i64, settings: AddressSettings, ) -> impl Future<Output = Result<Arc<UserContactLinkUpdatedResponse>, Self::Error>> + Send
Address commands Read more
Sourcefn api_send_messages(
&self,
command: ApiSendMessages,
) -> impl Future<Output = Result<Arc<NewChatItemsResponse>, Self::Error>> + Send
fn api_send_messages( &self, command: ApiSendMessages, ) -> impl Future<Output = Result<Arc<NewChatItemsResponse>, Self::Error>> + Send
Message commands Read more
Sourcefn api_update_chat_item(
&self,
command: ApiUpdateChatItem,
) -> impl Future<Output = Result<ApiUpdateChatItemResponse, Self::Error>> + Send
fn api_update_chat_item( &self, command: ApiUpdateChatItem, ) -> impl Future<Output = Result<ApiUpdateChatItemResponse, Self::Error>> + Send
Message commands Read more
Sourcefn api_delete_chat_item(
&self,
chat_ref: ChatRef,
chat_item_ids: Vec<i64>,
delete_mode: CIDeleteMode,
) -> impl Future<Output = Result<Arc<ChatItemsDeletedResponse>, Self::Error>> + Send
fn api_delete_chat_item( &self, chat_ref: ChatRef, chat_item_ids: Vec<i64>, delete_mode: CIDeleteMode, ) -> impl Future<Output = Result<Arc<ChatItemsDeletedResponse>, Self::Error>> + Send
Message commands Read more
Sourcefn api_delete_member_chat_item(
&self,
group_id: i64,
chat_item_ids: Vec<i64>,
) -> impl Future<Output = Result<Arc<ChatItemsDeletedResponse>, Self::Error>> + Send
fn api_delete_member_chat_item( &self, group_id: i64, chat_item_ids: Vec<i64>, ) -> impl Future<Output = Result<Arc<ChatItemsDeletedResponse>, Self::Error>> + Send
Message commands Read more
Sourcefn api_chat_item_reaction(
&self,
command: ApiChatItemReaction,
) -> impl Future<Output = Result<Arc<ChatItemReactionResponse>, Self::Error>> + Send
fn api_chat_item_reaction( &self, command: ApiChatItemReaction, ) -> impl Future<Output = Result<Arc<ChatItemReactionResponse>, Self::Error>> + Send
Message commands Read more
Sourcefn receive_file(
&self,
command: ReceiveFile,
) -> impl Future<Output = Result<ReceiveFileResponse, Self::Error>> + Send
fn receive_file( &self, command: ReceiveFile, ) -> impl Future<Output = Result<ReceiveFileResponse, Self::Error>> + Send
File commands Read more
Sourcefn api_add_member(
&self,
group_id: i64,
contact_id: i64,
member_role: GroupMemberRole,
) -> impl Future<Output = Result<Arc<SentGroupInvitationResponse>, Self::Error>> + Send
fn api_add_member( &self, group_id: i64, contact_id: i64, member_role: GroupMemberRole, ) -> impl Future<Output = Result<Arc<SentGroupInvitationResponse>, Self::Error>> + Send
Group commands Read more
Sourcefn api_join_group(
&self,
group_id: i64,
) -> impl Future<Output = Result<Arc<UserAcceptedGroupSentResponse>, Self::Error>> + Send
fn api_join_group( &self, group_id: i64, ) -> impl Future<Output = Result<Arc<UserAcceptedGroupSentResponse>, Self::Error>> + Send
Group commands Read more
Sourcefn api_accept_member(
&self,
group_id: i64,
group_member_id: i64,
member_role: GroupMemberRole,
) -> impl Future<Output = Result<Arc<MemberAcceptedResponse>, Self::Error>> + Send
fn api_accept_member( &self, group_id: i64, group_member_id: i64, member_role: GroupMemberRole, ) -> impl Future<Output = Result<Arc<MemberAcceptedResponse>, Self::Error>> + Send
Group commands Read more
Sourcefn api_members_role(
&self,
group_id: i64,
group_member_ids: Vec<i64>,
member_role: GroupMemberRole,
) -> impl Future<Output = Result<Arc<MembersRoleUserResponse>, Self::Error>> + Send
fn api_members_role( &self, group_id: i64, group_member_ids: Vec<i64>, member_role: GroupMemberRole, ) -> impl Future<Output = Result<Arc<MembersRoleUserResponse>, Self::Error>> + Send
Group commands Read more
Sourcefn api_block_members_for_all(
&self,
command: ApiBlockMembersForAll,
) -> impl Future<Output = Result<Arc<MembersBlockedForAllUserResponse>, Self::Error>> + Send
fn api_block_members_for_all( &self, command: ApiBlockMembersForAll, ) -> impl Future<Output = Result<Arc<MembersBlockedForAllUserResponse>, Self::Error>> + Send
Group commands Read more
Sourcefn api_remove_members(
&self,
command: ApiRemoveMembers,
) -> impl Future<Output = Result<Arc<UserDeletedMembersResponse>, Self::Error>> + Send
fn api_remove_members( &self, command: ApiRemoveMembers, ) -> impl Future<Output = Result<Arc<UserDeletedMembersResponse>, Self::Error>> + Send
Group commands Read more
Sourcefn api_leave_group(
&self,
group_id: i64,
) -> impl Future<Output = Result<Arc<LeftMemberUserResponse>, Self::Error>> + Send
fn api_leave_group( &self, group_id: i64, ) -> impl Future<Output = Result<Arc<LeftMemberUserResponse>, Self::Error>> + Send
Group commands Read more
Sourcefn api_list_members(
&self,
group_id: i64,
) -> impl Future<Output = Result<Arc<GroupMembersResponse>, Self::Error>> + Send
fn api_list_members( &self, group_id: i64, ) -> impl Future<Output = Result<Arc<GroupMembersResponse>, Self::Error>> + Send
Group commands Read more
Sourcefn api_new_group(
&self,
command: ApiNewGroup,
) -> impl Future<Output = Result<Arc<GroupCreatedResponse>, Self::Error>> + Send
fn api_new_group( &self, command: ApiNewGroup, ) -> impl Future<Output = Result<Arc<GroupCreatedResponse>, Self::Error>> + Send
Group commands Read more
Sourcefn api_new_public_group(
&self,
command: ApiNewPublicGroup,
) -> impl Future<Output = Result<ApiNewPublicGroupResponse, Self::Error>> + Send
fn api_new_public_group( &self, command: ApiNewPublicGroup, ) -> impl Future<Output = Result<ApiNewPublicGroupResponse, Self::Error>> + Send
Group commands Read more
Sourcefn api_get_group_relays(
&self,
group_id: i64,
) -> impl Future<Output = Result<Arc<GroupRelaysResponse>, Self::Error>> + Send
fn api_get_group_relays( &self, group_id: i64, ) -> impl Future<Output = Result<Arc<GroupRelaysResponse>, Self::Error>> + Send
Group commands Read more
Sourcefn api_add_group_relays(
&self,
group_id: i64,
relay_ids: Vec<i64>,
) -> impl Future<Output = Result<ApiAddGroupRelaysResponse, Self::Error>> + Send
fn api_add_group_relays( &self, group_id: i64, relay_ids: Vec<i64>, ) -> impl Future<Output = Result<ApiAddGroupRelaysResponse, Self::Error>> + Send
Group commands Read more
Sourcefn api_update_group_profile(
&self,
group_id: i64,
group_profile: GroupProfile,
) -> impl Future<Output = Result<Arc<GroupUpdatedResponse>, Self::Error>> + Send
fn api_update_group_profile( &self, group_id: i64, group_profile: GroupProfile, ) -> impl Future<Output = Result<Arc<GroupUpdatedResponse>, Self::Error>> + Send
Group commands Read more
Sourcefn api_create_group_link(
&self,
group_id: i64,
member_role: GroupMemberRole,
) -> impl Future<Output = Result<Arc<GroupLinkCreatedResponse>, Self::Error>> + Send
fn api_create_group_link( &self, group_id: i64, member_role: GroupMemberRole, ) -> impl Future<Output = Result<Arc<GroupLinkCreatedResponse>, Self::Error>> + Send
Group link commands Read more
Sourcefn api_group_link_member_role(
&self,
group_id: i64,
member_role: GroupMemberRole,
) -> impl Future<Output = Result<Arc<GroupLinkResponse>, Self::Error>> + Send
fn api_group_link_member_role( &self, group_id: i64, member_role: GroupMemberRole, ) -> impl Future<Output = Result<Arc<GroupLinkResponse>, Self::Error>> + Send
Group link commands Read more
Sourcefn api_delete_group_link(
&self,
group_id: i64,
) -> impl Future<Output = Result<Arc<GroupLinkDeletedResponse>, Self::Error>> + Send
fn api_delete_group_link( &self, group_id: i64, ) -> impl Future<Output = Result<Arc<GroupLinkDeletedResponse>, Self::Error>> + Send
Group link commands Read more
Sourcefn api_get_group_link(
&self,
group_id: i64,
) -> impl Future<Output = Result<Arc<GroupLinkResponse>, Self::Error>> + Send
fn api_get_group_link( &self, group_id: i64, ) -> impl Future<Output = Result<Arc<GroupLinkResponse>, Self::Error>> + Send
Group link commands Read more
Sourcefn api_add_contact(
&self,
command: ApiAddContact,
) -> impl Future<Output = Result<Arc<InvitationResponse>, Self::Error>> + Send
fn api_add_contact( &self, command: ApiAddContact, ) -> impl Future<Output = Result<Arc<InvitationResponse>, Self::Error>> + Send
Connection commands Read more
Sourcefn api_connect_plan(
&self,
command: ApiConnectPlan,
) -> impl Future<Output = Result<Arc<ConnectionPlanResponse>, Self::Error>> + Send
fn api_connect_plan( &self, command: ApiConnectPlan, ) -> impl Future<Output = Result<Arc<ConnectionPlanResponse>, Self::Error>> + Send
Connection commands Read more
Sourcefn api_connect(
&self,
command: ApiConnect,
) -> impl Future<Output = Result<ApiConnectResponse, Self::Error>> + Send
fn api_connect( &self, command: ApiConnect, ) -> impl Future<Output = Result<ApiConnectResponse, Self::Error>> + Send
Connection commands Read more
Sourcefn connect(
&self,
command: Connect,
) -> impl Future<Output = Result<ConnectResponse, Self::Error>> + Send
fn connect( &self, command: Connect, ) -> impl Future<Output = Result<ConnectResponse, Self::Error>> + Send
Connection commands Read more
Sourcefn api_accept_contact(
&self,
contact_req_id: i64,
) -> impl Future<Output = Result<Arc<AcceptingContactRequestResponse>, Self::Error>> + Send
fn api_accept_contact( &self, contact_req_id: i64, ) -> impl Future<Output = Result<Arc<AcceptingContactRequestResponse>, Self::Error>> + Send
Connection commands Read more
Sourcefn api_reject_contact(
&self,
contact_req_id: i64,
) -> impl Future<Output = Result<Arc<ContactRequestRejectedResponse>, Self::Error>> + Send
fn api_reject_contact( &self, contact_req_id: i64, ) -> impl Future<Output = Result<Arc<ContactRequestRejectedResponse>, Self::Error>> + Send
Connection commands Read more
Sourcefn api_list_contacts(
&self,
user_id: i64,
) -> impl Future<Output = Result<Arc<ContactsListResponse>, Self::Error>> + Send
fn api_list_contacts( &self, user_id: i64, ) -> impl Future<Output = Result<Arc<ContactsListResponse>, Self::Error>> + Send
Chat commands Read more
Sourcefn api_list_groups(
&self,
command: ApiListGroups,
) -> impl Future<Output = Result<Arc<GroupsListResponse>, Self::Error>> + Send
fn api_list_groups( &self, command: ApiListGroups, ) -> impl Future<Output = Result<Arc<GroupsListResponse>, Self::Error>> + Send
Chat commands Read more
Sourcefn api_get_chats(
&self,
command: ApiGetChats,
) -> impl Future<Output = Result<Arc<ApiChatsResponse>, Self::Error>> + Send
fn api_get_chats( &self, command: ApiGetChats, ) -> impl Future<Output = Result<Arc<ApiChatsResponse>, Self::Error>> + Send
Chat commands Read more
Sourcefn api_delete_chat(
&self,
chat_ref: ChatRef,
chat_delete_mode: ChatDeleteMode,
) -> impl Future<Output = Result<ApiDeleteChatResponse, Self::Error>> + Send
fn api_delete_chat( &self, chat_ref: ChatRef, chat_delete_mode: ChatDeleteMode, ) -> impl Future<Output = Result<ApiDeleteChatResponse, Self::Error>> + Send
Chat commands Read more
Sourcefn api_set_group_custom_data(
&self,
command: ApiSetGroupCustomData,
) -> impl Future<Output = Result<Arc<CmdOkResponse>, Self::Error>> + Send
fn api_set_group_custom_data( &self, command: ApiSetGroupCustomData, ) -> impl Future<Output = Result<Arc<CmdOkResponse>, Self::Error>> + Send
Chat commands Read more
Sourcefn api_set_contact_custom_data(
&self,
command: ApiSetContactCustomData,
) -> impl Future<Output = Result<Arc<CmdOkResponse>, Self::Error>> + Send
fn api_set_contact_custom_data( &self, command: ApiSetContactCustomData, ) -> impl Future<Output = Result<Arc<CmdOkResponse>, Self::Error>> + Send
Chat commands Read more
Sourcefn api_set_user_auto_accept_member_contacts(
&self,
command: ApiSetUserAutoAcceptMemberContacts,
) -> impl Future<Output = Result<Arc<CmdOkResponse>, Self::Error>> + Send
fn api_set_user_auto_accept_member_contacts( &self, command: ApiSetUserAutoAcceptMemberContacts, ) -> impl Future<Output = Result<Arc<CmdOkResponse>, Self::Error>> + Send
Chat commands Read more
Sourcefn show_active_user(
&self,
) -> impl Future<Output = Result<Arc<ActiveUserResponse>, Self::Error>> + Send
fn show_active_user( &self, ) -> impl Future<Output = Result<Arc<ActiveUserResponse>, Self::Error>> + Send
User profile commands Read more
Sourcefn create_active_user(
&self,
new_user: NewUser,
) -> impl Future<Output = Result<Arc<ActiveUserResponse>, Self::Error>> + Send
fn create_active_user( &self, new_user: NewUser, ) -> impl Future<Output = Result<Arc<ActiveUserResponse>, Self::Error>> + Send
User profile commands Read more
Sourcefn list_users(
&self,
) -> impl Future<Output = Result<Arc<UsersListResponse>, Self::Error>> + Send
fn list_users( &self, ) -> impl Future<Output = Result<Arc<UsersListResponse>, Self::Error>> + Send
User profile commands Read more
Sourcefn api_set_active_user(
&self,
command: ApiSetActiveUser,
) -> impl Future<Output = Result<Arc<ActiveUserResponse>, Self::Error>> + Send
fn api_set_active_user( &self, command: ApiSetActiveUser, ) -> impl Future<Output = Result<Arc<ActiveUserResponse>, Self::Error>> + Send
User profile commands Read more
Sourcefn api_delete_user(
&self,
command: ApiDeleteUser,
) -> impl Future<Output = Result<Arc<CmdOkResponse>, Self::Error>> + Send
fn api_delete_user( &self, command: ApiDeleteUser, ) -> impl Future<Output = Result<Arc<CmdOkResponse>, Self::Error>> + Send
User profile commands Read more
Sourcefn api_update_profile(
&self,
user_id: i64,
profile: Profile,
) -> impl Future<Output = Result<ApiUpdateProfileResponse, Self::Error>> + Send
fn api_update_profile( &self, user_id: i64, profile: Profile, ) -> impl Future<Output = Result<ApiUpdateProfileResponse, Self::Error>> + Send
User profile commands Read more
Sourcefn api_set_contact_prefs(
&self,
contact_id: i64,
preferences: Preferences,
) -> impl Future<Output = Result<Arc<ContactPrefsUpdatedResponse>, Self::Error>> + Send
fn api_set_contact_prefs( &self, contact_id: i64, preferences: Preferences, ) -> impl Future<Output = Result<Arc<ContactPrefsUpdatedResponse>, Self::Error>> + Send
User profile commands Read more
Sourcefn start_chat(
&self,
command: StartChat,
) -> impl Future<Output = Result<StartChatResponse, Self::Error>> + Send
fn start_chat( &self, command: StartChat, ) -> impl Future<Output = Result<StartChatResponse, Self::Error>> + Send
Chat management Read more
Sourcefn api_stop_chat(
&self,
) -> impl Future<Output = Result<Arc<ChatStoppedResponse>, Self::Error>> + Send
fn api_stop_chat( &self, ) -> impl Future<Output = Result<Arc<ChatStoppedResponse>, Self::Error>> + Send
Chat management Read more
Sourceimpl<C: Clone> Clone for XftpClient<C>
impl<C: Clone> Clone for XftpClient<C>
Sourcefn clone(&self) -> XftpClient<C>
fn clone(&self) -> XftpClient<C>
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<C: ClientApi> From<C> for XftpClient<C>
impl<C: ClientApi> From<C> for XftpClient<C>
Sourceimpl<C: ClientApi> Hook for XftpClient<C>
impl<C: ClientApi> Hook for XftpClient<C>
fn should_intercept(&self, kind: EventKind) -> bool
Sourcefn intercept_event(&mut self, event: Event)
fn intercept_event(&mut self, event: Event)
Hooks must not block the event stream; this method should be a cheap synchronous call.
Delegate heavy work to another thread or spawn async tasks internally.
Sourceimpl<C: ClientApi> XftpExt for XftpClient<C>
impl<C: ClientApi> XftpExt for XftpClient<C>
Sourcefn download_file<FID: Into<FileId>>(
&self,
file_id: FID,
) -> DownloadFileBuilder<'_, Self>
fn download_file<FID: Into<FileId>>( &self, file_id: FID, ) -> DownloadFileBuilder<'_, Self>
Begin downloading
file_id and return a builder to configure and await the result. Read moreAuto Trait Implementations
impl<C> Freeze for XftpClient<C>where
C: Freeze,
impl<C> !RefUnwindSafe for XftpClient<C>
impl<C> Send for XftpClient<C>where
C: Send,
impl<C> Sync for XftpClient<C>where
C: Sync,
impl<C> Unpin for XftpClient<C>where
C: Unpin,
impl<C> UnsafeUnpin for XftpClient<C>where
C: UnsafeUnpin,
impl<C> !UnwindSafe for XftpClient<C>