Module bot

Module bot 

High-level bot API.

Construction

Bots are supposed to be constructed via concrete backend builders. See [ffi::BotBuilder] and [ws::BotBuilder].

Bots vs Bot Farms

Constructing multiple bots via multiple BotBuilder invocations creates bots on separate SimpleX-Chat instances. For ws this would require spawning multiple CLI processes, for ffi the new chat controller is being created per bot under the hood. This is useful if you want to separate bot states completely(e.g. different databases encrypted by different keys). To manage multiple bots on the same SimpleX-Chat instance use bot farms. See [ws::BotFarmBuilder] and [ffi::BotFarmBuilder].

Re-exports

pub use farm::BotFarm;farm

Modules

farmfarm
Bot farm managing multiple bots on the same SimpleX instance

Structs

Bot
A cheaply cloneable handle to initialized SimpleX bot.
BotSettings
Passed to Bot::init to configure bot identity and startup behaviour.

Enums

BotProfileSettings
Connection