Structs
- ApiAccept
Contact - Connection commands
- ApiAccept
Contact Builder - Use builder syntax to set the inputs and finish with
build(). - ApiAccept
Member - Group commands
- ApiAccept
Member Builder - Use builder syntax to set the inputs and finish with
build(). - ApiAdd
Contact - Connection commands
- ApiAdd
Contact Builder - Use builder syntax to set the inputs and finish with
build(). - ApiAdd
Group Relays - Group commands
- ApiAdd
Group Relays Builder - Use builder syntax to set the inputs and finish with
build(). - ApiAdd
Member - Group commands
- ApiAdd
Member Builder - Use builder syntax to set the inputs and finish with
build(). - ApiBlock
Members ForAll - Group commands
- ApiBlock
Members ForAll Builder - Use builder syntax to set the inputs and finish with
build(). - ApiChat
Item Reaction - Message commands
- ApiChat
Item Reaction Builder - Use builder syntax to set the inputs and finish with
build(). - ApiConnect
- Connection commands
- ApiConnect
Builder - Use builder syntax to set the inputs and finish with
build(). - ApiConnect
Plan - Connection commands
- ApiConnect
Plan Builder - Use builder syntax to set the inputs and finish with
build(). - ApiCreate
Group Link - Group link commands
- ApiCreate
Group Link Builder - Use builder syntax to set the inputs and finish with
build(). - ApiCreate
MyAddress - Address commands
- ApiCreate
MyAddress Builder - Use builder syntax to set the inputs and finish with
build(). - ApiDelete
Chat - Chat commands
- ApiDelete
Chat Builder - Use builder syntax to set the inputs and finish with
build(). - ApiDelete
Chat Item - Message commands
- ApiDelete
Chat Item Builder - Use builder syntax to set the inputs and finish with
build(). - ApiDelete
Group Link - Group link commands
- ApiDelete
Group Link Builder - Use builder syntax to set the inputs and finish with
build(). - ApiDelete
Member Chat Item - Message commands
- ApiDelete
Member Chat Item Builder - Use builder syntax to set the inputs and finish with
build(). - ApiDelete
MyAddress - Address commands
- ApiDelete
MyAddress Builder - Use builder syntax to set the inputs and finish with
build(). - ApiDelete
User - User profile commands
- ApiDelete
User Builder - Use builder syntax to set the inputs and finish with
build(). - ApiGet
Chats - Chat commands
- ApiGet
Chats Builder - Use builder syntax to set the inputs and finish with
build(). - ApiGet
Group Link - Group link commands
- ApiGet
Group Link Builder - Use builder syntax to set the inputs and finish with
build(). - ApiGet
Group Relays - Group commands
- ApiGet
Group Relays Builder - Use builder syntax to set the inputs and finish with
build(). - ApiGroup
Link Member Role - Group link commands
- ApiGroup
Link Member Role Builder - Use builder syntax to set the inputs and finish with
build(). - ApiJoin
Group - Group commands
- ApiJoin
Group Builder - Use builder syntax to set the inputs and finish with
build(). - ApiLeave
Group - Group commands
- ApiLeave
Group Builder - Use builder syntax to set the inputs and finish with
build(). - ApiList
Contacts - Chat commands
- ApiList
Contacts Builder - Use builder syntax to set the inputs and finish with
build(). - ApiList
Groups - Chat commands
- ApiList
Groups Builder - Use builder syntax to set the inputs and finish with
build(). - ApiList
Members - Group commands
- ApiList
Members Builder - Use builder syntax to set the inputs and finish with
build(). - ApiMembers
Role - Group commands
- ApiMembers
Role Builder - Use builder syntax to set the inputs and finish with
build(). - ApiNew
Group - Group commands
- ApiNew
Group Builder - Use builder syntax to set the inputs and finish with
build(). - ApiNew
Public Group - Group commands
- ApiNew
Public Group Builder - Use builder syntax to set the inputs and finish with
build(). - ApiReject
Contact - Connection commands
- ApiReject
Contact Builder - Use builder syntax to set the inputs and finish with
build(). - ApiRemove
Members - Group commands
- ApiRemove
Members Builder - Use builder syntax to set the inputs and finish with
build(). - ApiSend
Messages - Message commands
- ApiSend
Messages Builder - Use builder syntax to set the inputs and finish with
build(). - ApiSet
Active User - User profile commands
- ApiSet
Active User Builder - Use builder syntax to set the inputs and finish with
build(). - ApiSet
Address Settings - Address commands
- ApiSet
Address Settings Builder - Use builder syntax to set the inputs and finish with
build(). - ApiSet
Contact Custom Data - Chat commands
- ApiSet
Contact Custom Data Builder - Use builder syntax to set the inputs and finish with
build(). - ApiSet
Contact Prefs - User profile commands
- ApiSet
Contact Prefs Builder - Use builder syntax to set the inputs and finish with
build(). - ApiSet
Group Custom Data - Chat commands
- ApiSet
Group Custom Data Builder - Use builder syntax to set the inputs and finish with
build(). - ApiSet
Profile Address - Address commands
- ApiSet
Profile Address Builder - Use builder syntax to set the inputs and finish with
build(). - ApiSet
User Auto Accept Member Contacts - Chat commands
- ApiSet
User Auto Accept Member Contacts Builder - Use builder syntax to set the inputs and finish with
build(). - ApiShow
MyAddress - Address commands
- ApiShow
MyAddress Builder - Use builder syntax to set the inputs and finish with
build(). - ApiStop
Chat - Chat management
- ApiStop
Chat Builder - Use builder syntax to set the inputs and finish with
build(). - ApiUpdate
Chat Item - Message commands
- ApiUpdate
Chat Item Builder - Use builder syntax to set the inputs and finish with
build(). - ApiUpdate
Group Profile - Group commands
- ApiUpdate
Group Profile Builder - Use builder syntax to set the inputs and finish with
build(). - ApiUpdate
Profile - User profile commands
- ApiUpdate
Profile Builder - Use builder syntax to set the inputs and finish with
build(). - Cancel
File - File commands
- Cancel
File Builder - Use builder syntax to set the inputs and finish with
build(). - Connect
- Connection commands
- Connect
Builder - Use builder syntax to set the inputs and finish with
build(). - Create
Active User - User profile commands
- Create
Active User Builder - Use builder syntax to set the inputs and finish with
build(). - List
Users - User profile commands
- List
Users Builder - Use builder syntax to set the inputs and finish with
build(). - Receive
File - File commands
- Receive
File Builder - Use builder syntax to set the inputs and finish with
build(). - Show
Active User - User profile commands
- Show
Active User Builder - Use builder syntax to set the inputs and finish with
build(). - Start
Chat - Chat management
- Start
Chat Builder - Use builder syntax to set the inputs and finish with
build().