pub enum StdMaybeCryptoFile<S: SimplexSecretBox> {
Plain(File),
Encrypted(EncryptedFile<S>),
}Available on crate feature
crypto only.Expand description
A sync file that is either plaintext or SimpleX-SecretBox encrypted.
Variants
Plain(File)
Encrypted(EncryptedFile<S>)
Implementations
Sourceimpl<S: SimplexSecretBox> StdMaybeCryptoFile<S>
impl<S: SimplexSecretBox> StdMaybeCryptoFile<S>
Sourcepub fn open<P: AsRef<Path>>(
path: P,
crypto_args: Option<FileCryptoArgs>,
) -> Result<Self>
pub fn open<P: AsRef<Path>>( path: P, crypto_args: Option<FileCryptoArgs>, ) -> Result<Self>
Opens the file read+write so that Self::prepare_for_overwrite works.
Use Self::open_read_only when write access is not needed or not available.
pub fn open_read_only<P: AsRef<Path>>( path: P, crypto_args: Option<FileCryptoArgs>, ) -> Result<Self>
pub fn create<P: AsRef<Path>>( path: P, crypto_args: Option<FileCryptoArgs>, ) -> Result<Self>
pub fn from_crypto_file(crypto_file: SxcCryptoFile) -> Result<Self>
pub fn from_crypto_file_read_only(crypto_file: SxcCryptoFile) -> Result<Self>
pub fn size_hint(&mut self) -> Result<usize>
pub fn crypto_args(&self) -> Option<&FileCryptoArgs>
pub fn prepare_for_overwrite(&mut self) -> Result<()>
Sourcepub fn put_auth_tag(self) -> Result<()>
pub fn put_auth_tag(self) -> Result<()>
Writes the AEAD auth tag for encrypted files; no-op for plain files.