pub struct DispatchChain<P, Ctx> { /* private fields */ }Expand description
Dispatcher builder. Obtained from EventStream::into_dispatcher.
Implementations
Sourceimpl<P, Ctx> DispatchChain<P, Ctx>where
P: EventParser,
impl<P, Ctx> DispatchChain<P, Ctx>where
P: EventParser,
pub fn with_ctx(events: EventStream<P>, ctx: Ctx) -> Self
Sourcepub fn seq_fallback<E, F>(self, f: F) -> Dispatcher<P, Ctx, Fallback<F>>
pub fn seq_fallback<E, F>(self, f: F) -> Dispatcher<P, Ctx, Fallback<F>>
The sequential version of Self::fallback
Sourcepub fn fallback<E, F, Fut>(self, f: F) -> Dispatcher<P, Ctx, Fallback<F>>
pub fn fallback<E, F, Fut>(self, f: F) -> Dispatcher<P, Ctx, Fallback<F>>
Accepts all events (crate::Event) unhandled by regular handlers.
It is mostly useful for debug logging. Prefer to remove this call in production because it
forces full parsing of all event types when by default only the events with set up handlers
get parsed.
Sourcepub fn seq<Ev, E, F>(self, f: F) -> Dispatcher<P, Ctx, Match<Ev, F>>
pub fn seq<Ev, E, F>(self, f: F) -> Dispatcher<P, Ctx, Match<Ev, F>>
Register the sequential handler. This call determines the Dispatcher type. You won’t be
able to mix seq with on, after calling this all handlers must be seq. See
Dispatcher::seq for full docs.
Sourcepub fn on<Ev, E, F, Fut>(self, f: F) -> Dispatcher<P, Ctx, Match<Ev, F>>
pub fn on<Ev, E, F, Fut>(self, f: F) -> Dispatcher<P, Ctx, Match<Ev, F>>
Register the concurrent handler. This call determines the Dispatcher type. You won’t be
able to mix seq with on, after calling this all handlers must be on. See
Dispatcher::on for full docs. Concurrent handlers require Ctx: 'static + Send + Clone. Ctx is getting cloned into each handler, ensure that impl Clone for Ctx is
cheap. If you need to mutate the Ctx you will have to use Arc<Mutex> or similar.