Structs
- Accepting
Business Request - Connection progress events
- Accepting
Business Request Builder - Use builder syntax to set the inputs and finish with
build(). - Accepting
Contact Request - Connection progress events
- Accepting
Contact Request Builder - Use builder syntax to set the inputs and finish with
build(). - Business
Link Connecting - Connection progress events
- Business
Link Connecting Builder - Use builder syntax to set the inputs and finish with
build(). - Chat
Error - Error events
- Chat
Error Builder - Use builder syntax to set the inputs and finish with
build(). - Chat
Errors - Error events
- Chat
Errors Builder - Use builder syntax to set the inputs and finish with
build(). - Chat
Item Reaction - Message events
- Chat
Item Reaction Builder - Use builder syntax to set the inputs and finish with
build(). - Chat
Item Updated - Message events
- Chat
Item Updated Builder - Use builder syntax to set the inputs and finish with
build(). - Chat
Items Deleted - Message events
- Chat
Items Deleted Builder - Use builder syntax to set the inputs and finish with
build(). - Chat
Items Statuses Updated - Message events
- Chat
Items Statuses Updated Builder - Use builder syntax to set the inputs and finish with
build(). - Connected
ToGroup Member - Group events
- Connected
ToGroup Member Builder - Use builder syntax to set the inputs and finish with
build(). - Contact
Connected - Contact connection events
- Contact
Connected Builder - Use builder syntax to set the inputs and finish with
build(). - Contact
Connecting - Connection progress events
- Contact
Connecting Builder - Use builder syntax to set the inputs and finish with
build(). - Contact
Deleted ByContact - Contact connection events
- Contact
Deleted ByContact Builder - Use builder syntax to set the inputs and finish with
build(). - Contact
SndReady - Contact connection events
- Contact
SndReady Builder - Use builder syntax to set the inputs and finish with
build(). - Contact
Updated - Contact connection events
- Contact
Updated Builder - Use builder syntax to set the inputs and finish with
build(). - Deleted
Member - Group events
- Deleted
Member Builder - Use builder syntax to set the inputs and finish with
build(). - Deleted
Member User - Group events
- Deleted
Member User Builder - Use builder syntax to set the inputs and finish with
build(). - Group
Chat Items Deleted - Message events
- Group
Chat Items Deleted Builder - Use builder syntax to set the inputs and finish with
build(). - Group
Deleted - Group events
- Group
Deleted Builder - Use builder syntax to set the inputs and finish with
build(). - Group
Link Connecting - Connection progress events
- Group
Link Connecting Builder - Use builder syntax to set the inputs and finish with
build(). - Group
Link Data Updated - Group events
- Group
Link Data Updated Builder - Use builder syntax to set the inputs and finish with
build(). - Group
Member Updated - Group events
- Group
Member Updated Builder - Use builder syntax to set the inputs and finish with
build(). - Group
Relay Updated - Group events
- Group
Relay Updated Builder - Use builder syntax to set the inputs and finish with
build(). - Group
Updated - Group events
- Group
Updated Builder - Use builder syntax to set the inputs and finish with
build(). - Host
Connected - Network connection events
- Host
Connected Builder - Use builder syntax to set the inputs and finish with
build(). - Host
Disconnected - Network connection events
- Host
Disconnected Builder - Use builder syntax to set the inputs and finish with
build(). - Joined
Group Member - Group events
- Joined
Group Member Builder - Use builder syntax to set the inputs and finish with
build(). - Joined
Group Member Connecting - Connection progress events
- Joined
Group Member Connecting Builder - Use builder syntax to set the inputs and finish with
build(). - Left
Member - Group events
- Left
Member Builder - Use builder syntax to set the inputs and finish with
build(). - Member
Accepted ByOther - Group events
- Member
Accepted ByOther Builder - Use builder syntax to set the inputs and finish with
build(). - Member
Blocked ForAll - Group events
- Member
Blocked ForAll Builder - Use builder syntax to set the inputs and finish with
build(). - Member
Role - Group events
- Member
Role Builder - Use builder syntax to set the inputs and finish with
build(). - Message
Error - Error events
- Message
Error Builder - Use builder syntax to set the inputs and finish with
build(). - NewChat
Items - Message events
- NewChat
Items Builder - Use builder syntax to set the inputs and finish with
build(). - NewMember
Contact Received Inv - Contact connection events
- NewMember
Contact Received InvBuilder - Use builder syntax to set the inputs and finish with
build(). - RcvFile
Accepted - File events
- RcvFile
Accepted Builder - Use builder syntax to set the inputs and finish with
build(). - RcvFile
Complete - File events
- RcvFile
Complete Builder - Use builder syntax to set the inputs and finish with
build(). - RcvFile
Descr Ready - File events
- RcvFile
Descr Ready Builder - Use builder syntax to set the inputs and finish with
build(). - RcvFile
Error - File events
- RcvFile
Error Builder - Use builder syntax to set the inputs and finish with
build(). - RcvFile
SndCancelled - File events
- RcvFile
SndCancelled Builder - Use builder syntax to set the inputs and finish with
build(). - RcvFile
Start - File events
- RcvFile
Start Builder - Use builder syntax to set the inputs and finish with
build(). - RcvFile
Warning - File events
- RcvFile
Warning Builder - Use builder syntax to set the inputs and finish with
build(). - Received
Contact Request - Contact connection events
- Received
Contact Request Builder - Use builder syntax to set the inputs and finish with
build(). - Received
Group Invitation - Group events
- Received
Group Invitation Builder - Use builder syntax to set the inputs and finish with
build(). - Sent
Group Invitation - Connection progress events
- Sent
Group Invitation Builder - Use builder syntax to set the inputs and finish with
build(). - SndFile
Complete Xftp - File events
- SndFile
Complete Xftp Builder - Use builder syntax to set the inputs and finish with
build(). - SndFile
Error - File events
- SndFile
Error Builder - Use builder syntax to set the inputs and finish with
build(). - SndFile
Warning - File events
- SndFile
Warning Builder - Use builder syntax to set the inputs and finish with
build(). - Subscription
Status - Network connection events
- Subscription
Status Builder - Use builder syntax to set the inputs and finish with
build(). - User
Joined Group - Group events
- User
Joined Group Builder - Use builder syntax to set the inputs and finish with
build().
Enums
Traits
- Event
Data - Generalization of event data