Available on crate feature
ffi only.Expand description
FFI backend that embeds the SimpleX-Chat library in-process via native Rust bindings.
Use BotBuilder to initialise the FFI runtime and get a ready-to-use Bot.
For lower-level access, init and init_with_config return a Client and an
EventStream directly.
Requires AGPL-3.0 and additional build configuration. See simploxide-sxcrt-sys.
Structs
- BotBuilder
- Builder for an FFI-backed
Bot. - Client
- A cheaply clonable high-level FFI client implementing
ClientApi - DbOpts
- Database options for a SimpleX chat instance.
- Default
User - The SimpleX user profile used to initialise the chat instance.
- Simplex
Version - Parses SimpleX version numbers in the form
MAJOR.MINOR.PATCH.HOTFIX. - Worker
Config - Configuration for the shared FFI worker thread.
Enums
- BotInit
Error - Error returned by
BotBuilder::launch. - Call
Error - Client
Error - See
crate::client_api::AllowUndocumentedResponsesif you don’t want to trigger an error when you receive undocumeted responses(you usually receive undocumented responses when your simplex-chat version is not compatible with the current simploxide-client version. Keep an eye on the Version compatability table) - Core
Init Error - Init
Error