BotBuilder

Struct BotBuilder 

pub struct BotBuilder { /* private fields */ }
Available on crate feature ffi only.
Builder for an FFI-backed Bot.

Implementations

Source

impl BotBuilder

pub fn new(name: impl Into<String>, db_opts: DbOpts) -> Self

Build a bot account (default).

pub fn with_default_user(self, user: DefaultUser) -> Self

Override the default user created for empty databases.

By default the default user name matches the bot name. This setting allows to create a user different from an active bot

pub fn auto_accept(self) -> Self

Create public address and auto accept users

pub fn auto_accept_with(self, welcome_message: impl Into<String>) -> Self

Self::auto_accept with a welcome message

pub fn with_avatar(self, avatar: ImagePreview) -> Self

Set the bot avatar during initialisation

pub fn with_profile(self, profile: Profile) -> Self

Update/create the whole bot profile on launch

pub fn with_preferences(self, prefs: Preferences) -> Self

Apply these preferences to the bot’s profile during initialisation.

pub fn max_event_latency(self, latency: Duration) -> Self

Set max permissible event latency. See WorkerConfig::max_event_latency for details

pub fn max_instances(self, instances: usize) -> Self

Set max concurrent SimpleX-Chat instances. See WorkerConfig::max_instances for details

pub async fn launch( self, ) -> Result<(Bot, EventStream<CoreResult<CoreEvent>>), BotInitError>

Initialise the SimpleX FFI runtime and return a ready-to-use bot.