ImagePreview

Struct ImagePreview 

pub struct ImagePreview { /* private fields */ }
Thumbnail for Image, Video, and Link messages. Also used as bot profile pictures. The source is stored lazily and resolved when resolve or try_resolve is called(either manually or automatically by message builders). Any error falls back to a default ~600 bytes in size JPEG placeholder.

Implementations

Source

impl ImagePreview

pub fn from_bytes(bytes: impl Into<Vec<u8>>) -> Self

Thumbnail from raw JPEG bytes. Fails on resolve if the encoded data URI exceeds 13333 bytes.

pub fn raw(uri: impl Into<String>) -> Self

Thumbnail from a pre-assembled `data:image/jpg;base64,{base64_contents} URI string.

pub fn from_file(path: impl AsRef<Path>) -> Self

Thumbnail loaded from a file; the file is read lazily when resolved.

pub fn kind(&self) -> PreviewKind

pub async fn resolve(self) -> String

Like Self::try_resolve but falls back to the default placeholder preview on error.

pub async fn try_resolve(self) -> Result<String, PreviewError>

Returns the preview as a data:image/jpg;base64,{base64_contents} URI. The source is assumed to be a valid JPEG(encoding is not validated) when multimedia feature is off or is lazily transcoded to JPEG when multimedia feature is on. Fails if the source cannot be read or the encoded URI exceeds 13333 bytes.