Remote controller support.
Allows a bot to accept an incoming remote control session from a SimpleX Desktop client, giving the desktop live access to the bot’s SimpleX instance.
Usage
ⓘ
let (rc, events) = events.hook_remote_control();
tokio::spawn(async move { bot.run(events).await });
// connection link received from admin via DM
bot.accept_remote_ctrl(&rc, &connection_link).await?;Structs
- Ctrl
Handle - Can be obtained via
EventStream::hook_remote_control.