pub struct CtrlHandle { /* private fields */ }Expand description
Can be obtained via EventStream::hook_remote_control.
Implementations
Sourceimpl CtrlHandle
impl CtrlHandle
Sourcepub async fn accept_remote_ctrl<C: ClientApi>(
&self,
client: &C,
link: &str,
) -> Result<(), CtrlError<C::Error>>
pub async fn accept_remote_ctrl<C: ClientApi>( &self, client: &C, link: &str, ) -> Result<(), CtrlError<C::Error>>
Connect to a remote controller using the connection link obtained via SimpleX-Desktop -> link mobile device menu.
Deadlock warning
This method awaits a remoteCtrlSessionCode event that only arrives when the event loop is
running concurrently. Calling this method from a sequential handler blocks the event loop
and deadlocks. Only call from a concurrent handler or outside the event dispatching logic
entirely.