Structs
- Accepting
Contact Request Response - Accepting
Contact Request Response Builder - Use builder syntax to set the inputs and finish with
build(). - Active
User Response - Active
User Response Builder - Use builder syntax to set the inputs and finish with
build(). - ApiChats
Response - ApiChats
Response Builder - Use builder syntax to set the inputs and finish with
build(). - Chat
CmdError Response - Chat
CmdError Response Builder - Use builder syntax to set the inputs and finish with
build(). - Chat
Item NotChanged Response - Chat
Item NotChanged Response Builder - Use builder syntax to set the inputs and finish with
build(). - Chat
Item Reaction Response - Chat
Item Reaction Response Builder - Use builder syntax to set the inputs and finish with
build(). - Chat
Item Updated Response - Chat
Item Updated Response Builder - Use builder syntax to set the inputs and finish with
build(). - Chat
Items Deleted Response - Chat
Items Deleted Response Builder - Use builder syntax to set the inputs and finish with
build(). - Chat
Running Response - Chat
Running Response Builder - Use builder syntax to set the inputs and finish with
build(). - Chat
Started Response - Chat
Started Response Builder - Use builder syntax to set the inputs and finish with
build(). - Chat
Stopped Response - Chat
Stopped Response Builder - Use builder syntax to set the inputs and finish with
build(). - CmdOk
Response - CmdOk
Response Builder - Use builder syntax to set the inputs and finish with
build(). - Connection
Plan Response - Connection
Plan Response Builder - Use builder syntax to set the inputs and finish with
build(). - Contact
Already Exists Response - Contact
Already Exists Response Builder - Use builder syntax to set the inputs and finish with
build(). - Contact
Connection Deleted Response - Contact
Connection Deleted Response Builder - Use builder syntax to set the inputs and finish with
build(). - Contact
Deleted Response - Contact
Deleted Response Builder - Use builder syntax to set the inputs and finish with
build(). - Contact
Prefs Updated Response - Contact
Prefs Updated Response Builder - Use builder syntax to set the inputs and finish with
build(). - Contact
Request Rejected Response - Contact
Request Rejected Response Builder - Use builder syntax to set the inputs and finish with
build(). - Contacts
List Response - Contacts
List Response Builder - Use builder syntax to set the inputs and finish with
build(). - Group
Created Response - Group
Created Response Builder - Use builder syntax to set the inputs and finish with
build(). - Group
Deleted User Response - Group
Deleted User Response Builder - Use builder syntax to set the inputs and finish with
build(). - Group
Link Created Response - Group
Link Created Response Builder - Use builder syntax to set the inputs and finish with
build(). - Group
Link Deleted Response - Group
Link Deleted Response Builder - Use builder syntax to set the inputs and finish with
build(). - Group
Link Response - Group
Link Response Builder - Use builder syntax to set the inputs and finish with
build(). - Group
Members Response - Group
Members Response Builder - Use builder syntax to set the inputs and finish with
build(). - Group
Relays AddFailed Response - Group
Relays AddFailed Response Builder - Use builder syntax to set the inputs and finish with
build(). - Group
Relays Added Response - Group
Relays Added Response Builder - Use builder syntax to set the inputs and finish with
build(). - Group
Relays Response - Group
Relays Response Builder - Use builder syntax to set the inputs and finish with
build(). - Group
Updated Response - Group
Updated Response Builder - Use builder syntax to set the inputs and finish with
build(). - Groups
List Response - Groups
List Response Builder - Use builder syntax to set the inputs and finish with
build(). - Invitation
Response - Invitation
Response Builder - Use builder syntax to set the inputs and finish with
build(). - Left
Member User Response - Left
Member User Response Builder - Use builder syntax to set the inputs and finish with
build(). - Member
Accepted Response - Member
Accepted Response Builder - Use builder syntax to set the inputs and finish with
build(). - Members
Blocked ForAll User Response - Members
Blocked ForAll User Response Builder - Use builder syntax to set the inputs and finish with
build(). - Members
Role User Response - Members
Role User Response Builder - Use builder syntax to set the inputs and finish with
build(). - NewChat
Items Response - NewChat
Items Response Builder - Use builder syntax to set the inputs and finish with
build(). - Public
Group Created Response - Public
Group Created Response Builder - Use builder syntax to set the inputs and finish with
build(). - Public
Group Creation Failed Response - Public
Group Creation Failed Response Builder - Use builder syntax to set the inputs and finish with
build(). - RcvFile
Accepted Response - RcvFile
Accepted Response Builder - Use builder syntax to set the inputs and finish with
build(). - RcvFile
Accepted SndCancelled Response - RcvFile
Accepted SndCancelled Response Builder - Use builder syntax to set the inputs and finish with
build(). - RcvFile
Cancelled Response - RcvFile
Cancelled Response Builder - Use builder syntax to set the inputs and finish with
build(). - Sent
Confirmation Response - Sent
Confirmation Response Builder - Use builder syntax to set the inputs and finish with
build(). - Sent
Group Invitation Response - Sent
Group Invitation Response Builder - Use builder syntax to set the inputs and finish with
build(). - Sent
Invitation Response - Sent
Invitation Response Builder - Use builder syntax to set the inputs and finish with
build(). - SndFile
Cancelled Response - SndFile
Cancelled Response Builder - Use builder syntax to set the inputs and finish with
build(). - User
Accepted Group Sent Response - User
Accepted Group Sent Response Builder - Use builder syntax to set the inputs and finish with
build(). - User
Contact Link Created Response - User
Contact Link Created Response Builder - Use builder syntax to set the inputs and finish with
build(). - User
Contact Link Deleted Response - User
Contact Link Deleted Response Builder - Use builder syntax to set the inputs and finish with
build(). - User
Contact Link Response - User
Contact Link Response Builder - Use builder syntax to set the inputs and finish with
build(). - User
Contact Link Updated Response - User
Contact Link Updated Response Builder - Use builder syntax to set the inputs and finish with
build(). - User
Deleted Members Response - User
Deleted Members Response Builder - Use builder syntax to set the inputs and finish with
build(). - User
Profile NoChange Response - User
Profile NoChange Response Builder - Use builder syntax to set the inputs and finish with
build(). - User
Profile Updated Response - User
Profile Updated Response Builder - Use builder syntax to set the inputs and finish with
build(). - Users
List Response - Users
List Response Builder - Use builder syntax to set the inputs and finish with
build().
Enums
- ApiAccept
Contact Response - ApiAccept
Member Response - ApiAdd
Contact Response - ApiAdd
Group Relays Response - ApiAdd
Member Response - ApiBlock
Members ForAll Response - ApiChat
Item Reaction Response - ApiConnect
Plan Response - ApiConnect
Response - ApiCreate
Group Link Response - ApiCreate
MyAddress Response - ApiDelete
Chat Item Response - ApiDelete
Chat Response - ApiDelete
Group Link Response - ApiDelete
Member Chat Item Response - ApiDelete
MyAddress Response - ApiDelete
User Response - ApiGet
Chats Response - ApiGet
Group Link Response - ApiGet
Group Relays Response - ApiGroup
Link Member Role Response - ApiJoin
Group Response - ApiLeave
Group Response - ApiList
Contacts Response - ApiList
Groups Response - ApiList
Members Response - ApiMembers
Role Response - ApiNew
Group Response - ApiNew
Public Group Response - ApiReject
Contact Response - ApiRemove
Members Response - ApiSend
Messages Response - ApiSet
Active User Response - ApiSet
Address Settings Response - ApiSet
Contact Custom Data Response - ApiSet
Contact Prefs Response - ApiSet
Group Custom Data Response - ApiSet
Profile Address Response - ApiSet
User Auto Accept Member Contacts Response - ApiShow
MyAddress Response - ApiStop
Chat Response - ApiUpdate
Chat Item Response - ApiUpdate
Group Profile Response - ApiUpdate
Profile Response - Cancel
File Response - Chat
CmdError - Connect
Response - Create
Active User Response - List
Users Response - Receive
File Response - Show
Active User Response - Start
Chat Response