ClientApiError

Trait ClientApiError 

pub trait ClientApiError: From<BadResponseError> + Error {
    // Required methods
    fn bad_response(&self) -> Option<&BadResponseError>;
    fn bad_response_mut(&mut self) -> Option<&mut BadResponseError>;
}

Required Methods

fn bad_response(&self) -> Option<&BadResponseError>

If current error is a bad response error return a reference to it

fn bad_response_mut(&mut self) -> Option<&mut BadResponseError>

If current error is a bad response error return a mut reference to it

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl ClientApiError for simploxide_client::ffi::ClientError

Available on crate feature ffi only.
Source

impl ClientApiError for simploxide_client::ws::ClientError

Available on crate feature websocket only.